<?php
 /**
 * About module
 * http://www.aa-team.com
 * ======================
 *
 * @package		CG
 * @author		Andrei Dinca, AA-Team
 * @version		1.0
 */
! defined( 'ABSPATH' ) and exit;

if(class_exists('CG_dashboard') != true) {
	class CG_dashboard {
		
		const WXR_VERSION = '1.0';
		
		/**
		 * parent storage
		 *
		 * @var array
		 */
		public $parent = array();
		
		private $action = '';
		private $db_name_games = '';
		private $wp_import = null;
		
		/**
		 * The constructor
		 */
		public function __construct( $parent=array() )
		{
			// load parent
			$this->parent = $parent;
			$this->db_name_games = CG()->db->prefix . 'contest_games';
		}

		public function get_popular_cast()
		{
			$cast = array();
			$cast_results = get_terms( 'cast', array(
			    'orderby'    	=> 'count',
			    'order' 		=> 'DESC',
			    'number'		=> 12,
			    'hide_empty' 	=> 0
			) );

			if( $cast_results && count($cast_results) > 0 ){
				foreach ($cast_results as $key => $value) {

					$image_ID = get_term_meta( $value->term_id, '_thumbnail', true );

					$cast[$value->term_id] = array(
						'name' => $value->name,
						'count' => $value->count,
						'thumb' => ( trim($image_ID) != "" ? wp_get_attachment_image_src( $image_ID, array(200, 300) )[0] : '' ),
					);
				}
			}

			return $cast;
		}

		public function get_popular_contests() {

			$contests = array();

			// step 2, get all already play questions

            $played_contests = CG()->db->get_results( 
                "
                SELECT a.contest_id, 
                		COUNT(DISTINCT user_id) as 'contest_hits' FROM " . ( $this->db_name_games ) . " 
                		as a GROUP BY a.contest_id ORDER BY contest_hits DESC LIMIT 5;
                ", ARRAY_A );


            foreach ($played_contests as $played_contest) {
            	$played_contest['poster_thumbnail'] = wp_get_attachment_image_src(get_term_meta($played_contest['contest_id'], 'contest-image-id', true))[0];
            	$contests[] = $played_contest;
            }
           
		
			return $contests;
		}

		public function get_popular_players() {
			$players = array();

			$users_that_played = CG()->db->get_results( 
                "
                SELECT DISTINCT a.user_id, 
                		COUNT(DISTINCT contest_id) as 'contests_played' FROM " . ( $this->db_name_games ) . " 
                		as a GROUP BY a.user_id ORDER BY contests_played DESC LIMIT 5;
                ", ARRAY_A );

            foreach ($users_that_played as $user_that_played) {
            	$user_that_played['poster_thumbnail'] = get_avatar_url($user_that_played['user_id']);
            	
            	$players[] = $user_that_played;
            }

			return $players;
		}
		
		public function print_interface()
		{
			$html = array();
			$plugin_register = (string) get_option( "_" . CG()->alias . "_register_html" );

			$html[] = '<div id="CG_iw-section-content" class="CG_iw-section-dashboard">';
			$html[] = 	'<div class="CG_iw-section-dashboard-row">';
			$html[] = 		'<div class="CG_iw-dashboard-box CG_iw-box-size-3">';
			$html[] = 			'<div class="CG_iw-dashboard-box-content">';
			$html[] = 				'<h3 class="dashboard-box-label">Popular Contests</h3>';
			$html[] = 				'<div class="CG_iw-dashboard-in-box-content">';

			$contests = $this->get_popular_contests();
			if( count($contests) > 0 ){
			$html[] = 					'<ul class="CG_iw-popular-products">';
				foreach ($contests as $product_key => $product_value) {
					
					$arr_params = array ( 'term_id' => $product_value['contest_id'], 'show_stats' => 'true' );
					$html[] = 				'<li>';
					$html[] = 					'<a href="' . add_query_arg( $arr_params, esc_url(get_permalink(CG()->settings['generator_page'] ))) . '">';


					if( trim($product_value['poster_thumbnail']) != "" ) {
						$html[] = 					'<img src="' . ( $product_value['poster_thumbnail'] ) . '" />';
					}

					$html[] = 					'</a>';
					$html[] = 					'<span>' . ( $product_value['contest_hits'] ) . ' plays</span>';
					$html[] = 				'</li>';
				}
				$html[] = 				'</ul>';
			}else{
				$html[] = '<div class="CG_iw-no-items">No contests yet! You can add new contests: <a href="' . ( admin_url( 'edit-tags.php?taxonomy=contests&post_type=question' ) ) . '">here</a></div>';
			}
			
			$html[] = 				'</div>';
			$html[] = 			'</div>';
			$html[] = 		'</div>';

			$html[] = 		'<div class="CG_iw-dashboard-box CG_iw-box-size-3">';
			$html[] = 			'<div class="CG_iw-dashboard-box-content">';
			$html[] = 				'<h3 class="dashboard-box-label">Popular Players</h3>';

			$html[] = 				'<div class="CG_iw-dashboard-in-box-content">';
			$players = $this->get_popular_players();
			if( count($players) > 0 ){
				$html[] = 					'<ul class="CG_iw-popular-products">';
				foreach ($players as $product_key => $product_value) {
					$html[] = 				'<li>';
					$html[] = 					'<a href="' . ( esc_url(get_edit_user_link( $product_value['user_id'] ))). '">';


					if( trim($product_value['poster_thumbnail']) != "" ) {
						$html[] = 					'<img src="' . ( $product_value['poster_thumbnail'] ) . '" />';
					}

					$html[] = 					'</a>';
					$html[] = 					'<span>' . ( $product_value['contests_played'] ) . ' plays</span>';
					$html[] = 				'</li>';
				}
				$html[] = 				'</ul>';

			}
			else {
				$html[] = '<div class="CG_iw-no-items">No players yet!</div>';
			}
			
			$html[] = 				'</div>';
			$html[] = 			'</div>';
			
			$html[] = 		'</div>';
			$html[] = 	'</div>';


			$html[] = 	'<div class="CG_iw-section-dashboard-row">';
			
			$html[] = 		'<div class="CG_iw-dashboard-box CG_iw-box-size-2">';
			$html[] = 			'<div class="CG_iw-dashboard-box-content">';
			$html[] = 				'<h3 class="dashboard-box-label">Product Support</h3>';
			$html[] = 				'<div class="CG_iw-dashboard-in-box-content">';
			$html[] = 					'<div class="CG_iw-row-icons">';
			$html[] = 						'<i class="fa fa-file-text-o"></i>';
			$html[] = 						'<div class="CG_iw-icons-title">';
			$html[] = 							'<p class="CG_iw-icons-strong">Online Documentation</p>';
			$html[] = 							'<p>The best start for <strong>' . ( strip_tags( $this->parent->plugin_name ) ) . '</strong> beginners</p>';
			$html[] = 						'</div>';
			$html[] = 					'</div>';
			$html[] = 					'<div class="CG_iw-row-icons">';
			$html[] = 						'<i class="fa fa-life-ring"></i>';
			$html[] = 						'<div class="CG_iw-icons-title">';
			$html[] = 							'<p class="CG_iw-icons-strong">Ticket Support</p>';
			$html[] = 							'<p>Direct help from our qualified support team</p>';
			if( !$plugin_register && trim($plugin_register) == "" ){
				$html[] = 						'<a href="#" class="CG_iw-dashboard-button CG_iw-color-red CG_iw-require_register">Unlock Now</a>';
			}else{
				$html[] = 						'<a href="http://support.aa-team.com/" target="_blank" class="CG_iw-dashboard-button CG_iw-color-yellow">Open New Ticket</a>';
			}
			$html[] = 						'</div>';
			$html[] = 					'</div>';
			$html[] = 					'<div class="CG_iw-row-icons">';
			$html[] = 						'<i class="fa fa-money"></i>';
			$html[] = 						'<div class="CG_iw-icons-title">';
			$html[] = 							'<p class="CG_iw-icons-strong">Custom Modifications</p>';
			$html[] = 							'<p>Direct help from our qualified dev and design team</p>';
			if( !$plugin_register && trim($plugin_register) == "" ){
				$html[] = 						'<a href="#" class="CG_iw-dashboard-button CG_iw-color-red CG_iw-require_register">Unlock Now</a>';
			}else{
				$html[] = 						'<a href="http://support.aa-team.com/custom-modifications/" target="_blank" class="CG_iw-dashboard-button CG_iw-color-yellow">Request a Quote</a>';
			}
			$html[] = 						'</div>';
			$html[] = 					'</div>';
			$html[] = 				'</div>';
			$html[] = 			'</div>';
			$html[] = 		'</div>';
			/*
			global $current_user;
      		get_currentuserinfo();
			*/

      		$current_user = wp_get_current_user();

			$html[] = 		'<div class="CG_iw-dashboard-box CG_iw-box-size-2">';
			$html[] = 			'<div class="CG_iw-dashboard-box-content">';

			if( $plugin_register && trim($plugin_register) != "" ){
				$html[] = 				'<h3 class="dashboard-box-label">Your plugin is activated</h3>';
				$html[] = 				'<div class="CG_iw-dashboard-in-box-content CG_iw-aa-register-text">' . ( $plugin_register ) . '</div>';
			}else{

				$html[] = 				'<h3 class="dashboard-box-label">Plugin Activation</h3>';
				$html[] = 				'<div class="CG_iw-dashboard-in-box-content">';
				$html[] = 					'<form class="CG_iw-register_plugin" action="" method="POST">';
				$html[] = 						'<div class="CG_iw-row-icons">';
				$html[] = 							'<i class="fa fa-key"></i>';
				$html[] = 							'<div class="CG_iw-icons-title">';
				$html[] = 								'<p class="CG_iw-icons-strong">Item Purchase Code (IPC)</p>';
				$html[] = 								'<p>You can learn how to find your purchase code <a href="http://support.aa-team.com/themes/default/assets/images/ipc-help.png" target="_blank">here</a></p>';
				$html[] = 							'</div>';
				$html[] = 						'</div>';
				$html[] = 						'<input type="text" value="" style="width:100%" class="CG_iw-dashboard-input" name="CG_iw-validation-token" placeholder="IPC Code">';
				$html[] = 						'<input type="text" value="' . ( $current_user->user_email ) . '" style="width:100%" class="CG_iw-dashboard-input" name="CG_iw-validation-email" placeholder="Register email">';
				$html[] = 						'<p>Reminder! The Regular License is for One Install Only!</p>';
				$html[] = 						'<input type="button" class="CG_iw-dashboard-button CG_iw-color-yellow" value="Register the code" />';
				$html[] = 					'</form>';
				$html[] = 				'</div>';
			}
			$html[] = 			'</div>';
			$html[] = 		'</div>';

			$html[] = 		'<div class="CG_iw-dashboard-box CG_iw-box-size-2">';
			$html[] = 			'<div class="CG_iw-dashboard-box-content">';
			$html[] = 				'<h3 class="dashboard-box-label">System Requirements</h3>';
			$html[] = 				'<div class="CG_iw-dashboard-in-box-content">';
			$html[] = 					'<table class="CG_iw-system-req">';
			$html[] = 						'<tr>';
			$html[] = 							'<td width="55%">' . ( is_multisite() ? 'WPMU' : 'WP' ) . ' Version:</td>';
			$html[] = 							'<td><span class="CG_iw-success"><i class="fa fa-check-square"></i></span></td>';
			$html[] = 							'<td width="30%">' . get_bloginfo('version') . ' </td>';
			$html[] = 						'</tr>';

			$html[] = 						'<tr>';
			$html[] = 							'<td width="55%">Uploads folder writable</td>';
			$html[] = 							'<td><span class="CG_iw-success"><i class="fa fa-check-square"></i></span></td>';
			$html[] = 							'<td width="30%"></td>';
			$html[] = 						'</tr>';

			$html[] = 						'<tr>';
			$html[] = 							'<td width="55%">Max Upload Size:</td>';
			$html[] = 							'<td><span class="CG_iw-success"><i class="fa fa-exclamation-circle"></i></span></td>';
			$html[] = 							'<td width="30%">' . ( size_format( wp_max_upload_size() ) ) . '</td>';
			$html[] = 						'</tr>';


			$allow_remote_get = (boolean) get_option( "_CG_allow_remote_get" );

			if( $allow_remote_get === false ){
				$response = wp_remote_get( 'http://google.com' );
				if( isset($response['body']) && trim($response['body']) != "" ){
					$allow_remote_get = true;
					update_option( "_CG_allow_remote_get", true );
				}
			}

			$html[] = 						'<tr>';
			$html[] = 							'<td width="55%">Remote GET:</td>';
			if( $allow_remote_get ){
				$html[] = 						'<td><span class="CG_iw-success"><i class="fa fa-exclamation-circle"></i></span></td>';
			}else{
				$html[] = 						'<td><span class="CG_iw-error"><i class="fa fa-check-square"></i></span></td>';
			}
			$html[] = 							'<td width="30%"></td>';
			$html[] = 						'</tr>';
			$html[] = 						'<tr>';
			$html[] = 							'<td>Your Theme</td>';
			$template = get_option( 'template' );
			$themes = wp_get_themes();
			$theme = $themes[$template];

			//var_dump('<pre>',$theme ,'</pre>'); die; 
			$html[] = 							'<td><span class="CG_iw-success"><i class="fa fa-check-square"></i></span></td>';
			$html[] = 							'<td><a href="' . ( admin_url( '/themes.php' ) ) . '"><img width="80" src="' . ( esc_url( $theme->get_screenshot() ) ) . '" /></a></td>';
			$html[] = 						'</tr>';

			$html[] = 						'<tr>';
			$html[] = 							'<td width="55%">WP DEBUG:</td>';
			$html[] = 							'<td rowspan="2">' . (  defined('WP_DEBUG') && WP_DEBUG === true ? 'YES' : "NO" ) . '</td>';
			$html[] = 						'</tr>';

			$html[] = 					'</table>';
			$html[] = 				'</div>';
			$html[] = 			'</div>';
			$html[] = 		'</div>';

			$html[] = 	'</div>';
			$html[] = '</div>';
			
			return implode( "\n", $html );
		}
	}
}