<?php 
!defined('ABSPATH') and exit;

if (class_exists('CG_Game') != true) {
    
    class CG_Game
    {
        /*
         * Some required plugin information
         */
        const VERSION = '1.0';

        private $player_id = 0;
        private $db_name = '';
        private $alias = '';


        /*
         * Required __construct() function that initalizes the CG_Game
         */
        public function __construct( $the_plugin=array() )
        {
            $this->the_plugin = $the_plugin;
            $this->db_name = $the_plugin->db->prefix . 'contest_games';
            $this->alias = $the_plugin->alias;


            add_action( "init", array($this, 'player_login' ) );
        }

        public function player_login()
        {
            $this->player_id = get_current_user_id();
            //$this->player_id = 1;
        }

        public function start_contest( $contest_id=0 )
        {

            if( (int)$this->player_id == 0 ){
                die( json_encode( array( 
                    'status' => 'invalid',
                    'msg' => 'Please login first!'
                ) ) ); 
            }

            if( $contest_id == 0 ){
                die( json_encode( array( 
                    'status' => 'invalid',
                    'msg' => 'Invalid contest ID'
                ) ) ); 
            }

            $_SESSION['CG']['game']['contest_id'] = $contest_id; 
            $_SESSION['CG']['game']['start_date'] = time();
            $_SESSION['CG']['game']['questions'] = array();
            $_SESSION['CG']['game']['total_points'] = 0;

            /* !!! tmp */
            die( json_encode( array( 
                'status' => 'valid'
            ) ) ); 
        }

        public function get_all_questions_by_cid( $contest_id=0 )
        {
            // step 1, get all questions from custom contest id
            $args = array( 
                'post_type' => 'question',
                'posts_per_page' => -1,
                'fields' => 'ids',
                'tax_query' => array(
                    array(
                        'taxonomy' => 'contests',
                        'field' => 'tag_ID',
                        'terms' => $contest_id
                    ),
                ),
            );

            $all_questions = array();
            $the_query = new WP_Query( $args );
            if ( $the_query->have_posts() ) {
                if( isset($the_query->posts) && count($the_query->posts) > 0 ){
                    foreach ($the_query->posts as $post) {
                        $all_questions[$post] = $post;
                    }
                }
            }

            // step 2, get all already play questions
            $played_questions = CG()->db->get_results( CG()->db->prepare (
                "
                SELECT question_id
                FROM " . ( $this->db_name ) . "
                WHERE 1=1 
                    AND contest_id = %d 
                    AND user_id = %d 
                "
            , $contest_id, $this->player_id), ARRAY_A );

            if( $played_questions && count($played_questions) > 0 ){ 
                foreach ($played_questions as $question_id) {
                    if( in_array( $question_id['question_id'], $all_questions) ){
                        unset( $all_questions[$question_id['question_id']] );
                    }
                }
            }
             
            if( count($all_questions) > 0 ){
                return array_values( $all_questions );
            }

            return array();
        }

        public function print_no_more_question( $contest_id=0 )
        {
            if ($contest_id != 0) {
                unset( $_SESSION['CG']['game']['contest_id'] );

                $term = get_term( $contest_id, 'contests' );

                $termMeta = get_term_meta($term->term_id);

                $obtained_points = CG()->db->get_results( CG()->db->prepare (
                    "
                    SELECT SUM(points_nb) as obtained_points
                    FROM " . ( $this->db_name ) . "
                    WHERE 1=1 
                        AND contest_id = %d 
                        AND user_id = %d 
                        "
                    , $contest_id, $this->player_id), ARRAY_A );

                if ( !isset($termMeta['contest_finish_time'][0]) ) {
                     $elapsed_time = time() - $_SESSION['CG']['game']['start_date'];

                     update_term_meta ( $term->term_id, 'contest_finish_time', $elapsed_time);
                }
                else {
                    $elapsed_time = $termMeta['contest_finish_time'][0];

                }
               
                
                die( json_encode( array( 
                    'status' => 'invalid',
                    'html' => '<div class="CG-contest-content CG-contest-finished">
                                    <h3 class="CG-title">' . $termMeta['finish_page_title'][0] . '</h3>
                                    <div class="CG-finish-text">
                                        <p>' . __('You have finished the contest in ' . $this->seconds_to_time($elapsed_time) . ' and earned ' .  $obtained_points[0]['obtained_points'], 'CG') . ' points.</p>
                                        ' . (($termMeta['finish_page_extra_text'][0] != null) ? ('<p>' . $termMeta['finish_page_extra_text'][0] . '</p>') : '') . '

                                    </div>
                                </div>'
                ) ) );
            } else {
                die ('Go away...');
            }
            
        }

        public function check_if_game_start( $contest_id=0 )
        { 
            // !!! tmp 
            //$this->start_contest( $contest_id );

            //return true;
            //unset($_SESSION['CG']['game']['contest_id']);
            if( isset($_SESSION['CG']['game']['contest_id']) && (int)$_SESSION['CG']['game']['contest_id'] > 0 ){

                if( $_SESSION['CG']['game']['contest_id'] == $contest_id ){
                    return true;
                }
            }

            return false; 
        }

        private function get_contest_by_id( $contest_id=0 )
        {
            if( $contest_id > 0 ){
                $term = get_term( $contest_id, 'contests' );

                if( $term == NULL ){
                    return false;
                }

                //die( var_dump( "<pre>", $term->term_id  , "<pre>" ) . PHP_EOL .  __FILE__ . ":" . __LINE__  ); 
                $termMeta = get_term_meta($term->term_id);
                //die( var_dump( "<pre>", $termMeta['start_game_button_text'][0]  , "<pre>" ) . PHP_EOL .  __FILE__ . ":" . __LINE__  ); 
                $image_id = $termMeta['contest-image-id'];
                $contest_questions = $term->count;
//die( var_dump( "<pre>", $contest_questions  , "<pre>" ) . PHP_EOL .  __FILE__ . ":" . __LINE__  ); 

                return array(
                    'name' => $term->name,
                    'description' => $term->description,
                    'max_points_nb' => $termMeta['max_points_nb'][0],
                    'unblur_seconds' => $termMeta['question_unblur_seconds'][0],
                    'image_url' => wp_get_attachment_image_src ( $image_id[0], 'large' ),
                    'questions' => $contest_questions,
                    'start_game_button_text' => $termMeta['start_game_button_text'][0],
                    'continue_game_button_text' => $termMeta['continue_game_button_text'][0],
                    'availibility' => array(
                        'from' => strtotime($termMeta['start_game_date'][0]),
                        'to' => strtotime($termMeta['end_game_date'][0])
                    )
                ); 
            }
        }

        public function check_if_game_already_started ( $contest_id=0 ) {
            

            if ($this->check_if_game_start( $contest_id ) == true) {
                return true;
            }
            else {
            
                $played_questions = CG()->db->get_results( CG()->db->prepare (
                "
                SELECT COUNT(*) as played_questions
                FROM " . ( $this->db_name ) . "
                WHERE 1=1 
                    AND contest_id = %d 
                    AND user_id = %d 
                "
            , $contest_id, $this->player_id), ARRAY_A );
               
                if ($played_questions[0]['played_questions'] != 0) {
                    return true;
                }
                else {
                    return false;
                }
            }
             
            
        }

        public function print_game_start_html ( $contest_id=0, $continue=false ) {
            $html = array();

            $contest = $this->get_contest_by_id( $contest_id );
            $termID = get_term($contest_id)->term_id;

            $image_id = get_term_meta ( $termID, 'contest-image-id', true );


            $html[] = '<div id="' . ( $this->alias )  . '">';
            $html[] =   '<div class="' . ( $this->alias )  . '-wrapper">';
            $html[] =       ' <div class="' . ( $this->alias )  . '-body ' . ( $this->alias )  . '-intro">';
            $html[] =           '<div class="' . ( $this->alias )  . '-contest-content">';
            $html[] =               '<div class="' . ( $this->alias )  . '-media">';
            $html[] =                   '<img class="' . ( $this->alias )  . '-image-to-guess" src="' . ( $contest['image_url'][0] ) . '" />';
            $html[] =               '</div>';
            $html[] =           '<div class="' . ( $this->alias )  . '-text">';
            $html[] =               '<h3 class="' . ( $this->alias )  . '-title">' . ( $contest['name'] ) . '</h3>';
            $html[] =               '<h6 class="' . ( $this->alias )  . '-duration">Availibility: ' . ( date( "d F Y", $contest['availibility']['from'] ) ) . ' - ' . ( date( "d F Y", $contest['availibility']['to'] ) ) . '</h6>';
            $html[] =               '<div class="' . ( $this->alias )  . '-intro-text">';
            $html[] =                   '<p>' . ( $contest['description'] ) . '</p>';
            $html[] =               '</div>';
            $html[] =               '<a href="' . esc_url(get_permalink(CG()->settings['generator_page'])) . '?term_id=' . $termID . '"' . (($contest['availibility']['from'] > time() || $contest['availibility']['to'] < time()) ? ' disabled="disabled"' : '')  . ' class="' . ( $this->alias )  . '-button ' . ( $this->alias )  . '-start">' . (($continue == false ) ? $contest['start_game_button_text'] : $contest['continue_game_button_text']) . '</a>';
            $html[] =           '</div>';
            $html[] =        '</div>';
            $html[] =      '</div>';
            $html[] =   '</div>';
            $html[] = '</div>';

            die( json_encode( array( 
                'status' => 'valid',
                'page' => 'start',
                'html' => implode( "\n", $html )
            ) ) );
        }


        public function game_start_html( $contest_id=0, $continue=false )
        {
            $game_started = $this->check_if_game_already_started( $contest_id );

            if ($game_started == true) {
                if( $contest_id > 0 ){
                    $all = $this->get_all_questions_by_cid( $contest_id );

                    if( count($all) == 0 ){
                        $this->print_no_more_question($contest_id);
                    }
                    else {
                        $this->print_game_start_html($contest_id, true);
                    }
                }
            }
            else {
                $this->print_game_start_html($contest_id);
            }

            
        }

        private function seconds_to_time( $seconds=0 ) 
        {
            $dtF = new DateTime('@0');
            $dtT = new DateTime("@$seconds");
            return $dtF->diff($dtT)->format('%i minutes and %s seconds');
        }

        public function obtain_youtube_embed_url ( $normal_url ) {

            preg_match('/[\\?\\&]v=([^\\?\\&]+)/', $normal_url, $matches);
            $id = $matches[1];

            return "https://www.youtube.com/embed/" . $id;
        }

        public function continue_contest ( $contest_id=0 ) {

            $this->game_start_html($contest_id, true);
        }

        public function print_next_question_html( $params=array(), $contest_id=0, $game_id=0 )
        {
            $html = array();

            $current_game = $_SESSION['CG']['game'];
            $_SESSION['CG']['game']['questions'][] = $params['post']->ID;


            $contest = $this->get_contest_by_id( $contest_id );
            $duration = time() - $current_game['start_date'];

            //die( var_dump( "<pre>", $params  , "<pre>" ) . PHP_EOL .  __FILE__ . ":" . __LINE__  ); 
            
            $html[] = '<div class="' . ( $this->alias )  . '-contest-content" data-timeelapsed="' . $duration .'">';
            $html[] =   '<div class="' . ( $this->alias )  . '-current-score">';
            $html[] =       '<img src="'. $this->the_plugin->path( 'APP_URL',  'assets/images/upper-score-background.png') .'" />';
            $html[] =       '<span class="' . ( $this->alias )  . '-current-score-amount-1">' . ( $contest['max_points_nb'] ) . '</span>';
            $html[] =       '<span class="' . ( $this->alias )  . '-current-score-amount-2">points left</span>';
            $html[] =   '</div>';
            $html[] =   '<div class="' . ( $this->alias )  . '-media">';

            if ($params['question_type'] == 'image' ) {
                $html[] =       '<div class="' . ( $this->alias )  . '-img-to-guess">';
                $html[] =           $params['image'];
                $html[] =       '</div>';
            }
            else 
                if ($params['question_type'] == 'video') {
                    
                    $html[] =       '<div class="' . ( $this->alias )  . '-video-to-guess">';
                    $html[] =           '<iframe id="ytplayer" type="text/html" width="480" height="270" src="' . $this->obtain_youtube_embed_url($params['video_url']) . '?autoplay=1&rel=0&amp;controls=0&amp;showinfo=0" frameborder="0" allowfullscreen></iframe>';
                    $html[] =       '</div>';
                }

            $html[] =   '<div class="' . ( $this->alias )  . '-img-difficulty-range">';
            $html[] =       '<span class="' . ( $this->alias )  . '-img-difficulty-hard">hard</span>';
            $html[] =       '<span class="' . ( $this->alias )  . '-img-difficulty-easy">easy</span>';
            $html[] =       '<div class="' . ( $this->alias )  . '-img-difficulty-time-left">';
            $html[] =           '<div class="' . ( $this->alias )  . '-img-difficulty-time-passed">';
            $html[] =               '<span class="' . ( $this->alias )  . '-img-difficulty-time-handle"></span>';
            $html[] =           '</div>';
            $html[] =        '</div>';

            $html[] =       '<span class="' . ( $this->alias )  . '-img-difficulty-seconds">' . ( $contest['unblur_seconds'] ) . '</span>';
            $html[] =   ' </div>';
            $html[] =   '</div>';
            $html[] =   '<div class="' . ( $this->alias )  . '-text">';
            $html[] =       '<h3 class="' . ( $this->alias )  . '-title">' . ( $params['post']->post_title ) . '</h3>';
            $html[] =       '<h6 class="' . ( $this->alias )  . '-duration">Availibility: ' . ( date( "d F Y", $contest['availibility']['from'] ) ) . ' - ' . ( date( "d F Y", $contest['availibility']['to'] ) ) .'</h6>';
            $html[] =       '<div class="' . ( $this->alias )  . '-intro-text">';
            $html[] =           '<p>' . ( $params['post']->post_content ) . '</p>';
            $html[] =       '</div>';
            $html[] =       '<form class="' . ( $this->alias )  . '-question-form" action="" data-gameid="' . ( $game_id ) . '" data-id="' . ( $params['post']->ID ) . '">';
            $html[] =           '<ul>';
            if( count($params['answers']) > 0 ){
                $cc = 0;
                foreach ($params['answers'] as $answer) { 
                    $html[] = '<li><input id="CG-ans-' . ( $cc ) . '" name="answer" type="radio" class="radio" value="' . ( $answer['text'] ) . '"> <label for="CG-ans-' . ( $cc ) . '">' . ( $answer['text'] ) . '</label></li>';
                    $cc++;
                }
            }
            $html[] =           '</ul>';
            $html[] =           '<button class="' . ( $this->alias )  . '-button ' . ( $this->alias )  . '-submit">Submit</button>';
            $html[] =       '</form>';
            $html[] =   '</div>';
            $html[] = '</div>';
            $html[] = '<div class="' . ( $this->alias )  . '-info-boxes">';
            $html[] =   '<div class="' . ( $this->alias )  . '-finished-questions">« ' . ( count($current_game['questions']) ) . ' finished questions</div>';
            $html[] =   '<div class="' . ( $this->alias )  . '-info">';
            $html[] =       '<div class="' . ( $this->alias )  . '-quiz-duration">';

            
            $html[] =       'duration: <span class="' . ( $this->alias )  . '-quiz-duration-time">' . ( $this->seconds_to_time( $duration ) ) . '</span>';
            $html[] =   '</div>';
            $html[] =   '<div class="' . ( $this->alias )  . '-points">';
            $html[] =       '<div class="' . ( $this->alias )  . '-points">';
            $html[] =           'points: <span class="' . ( $this->alias )  . '-points-amount">' . ( $current_game['total_points'] ) . '</span>';
            $html[] =       '</div>';
            $html[] =   '</div>';
            $html[] = '</div>';
            $html[] =   '<div class="' . ( $this->alias )  . '-remaining-questions">» ' . ( ($contest['questions'] - 1) - count($current_game['questions']) ) . ' more questions</div>';

            //die( var_dump( "<pre>", $current_game , "<pre>" ) . PHP_EOL .  __FILE__ . ":" . __LINE__  ); 
            
            die( json_encode( array( 
                'status' => 'valid',
                'page' => 'question',
                'contest' => array(
                    'game_id' => $game_id,
                    'unblur_seconds' => $contest['unblur_seconds'],
                    'max_points_nb' => $contest['max_points_nb']
                ),
                'html' => implode( "\n", $html ),
                'question' => array(
                    'title' => $params['post']->post_title,
                    'text' => $params['post']->post_content,
                    'image_url' => $params['image_url'],
                    'answers' => $params['answers'] 
                )
            ) ) );
        }

        private function use_question( $params=array() )
        {
            CG()->db->insert( 
                $this->db_name, 
                array( 
                    'user_id' => $this->player_id,
                    'question_id' => $params['post']->ID,
                    'contest_id' => $params['contest_id'],
                    'answer_status' => $params['status']
                ), 
                array( 
                    '%d', 
                    '%d', 
                    '%d', 
                    '%s' 
                ) 
            );

            return CG()->db->insert_id;
        }

        private function check_if_valid_contest_id( $contest_id=0 )
        {
            $contest = $this->get_contest_by_id( $contest_id );
            if( $contest == false ) {
                die( json_encode( array( 
                'status' => 'invalid',
                'html' => '<div class="CG-contest-content">
                                <h3 class="CG-title">Invalid contest ID</h3>
                                <div class="CG-finish-text">
                                    <p>' . __('No contest found.', 'CG') . '</p>
                                </div>
                            </div>'
                ) ) );
            }
        }

        public function get_next_question( $contest_id=0 )
        {

            $this->check_if_valid_contest_id( $contest_id );

            if( $contest_id > 0 ){
                $all = $this->get_all_questions_by_cid( $contest_id );

                if( count($all) == 0 ){
                    $this->print_no_more_question($contest_id);
                }else{
                    // tmp!!
                    // if( count($all) == 0 ){
                    //     $this->print_no_more_question(); 
                    // }
                    
                    $all = array_values( $all ); 
                    
                    $question_id = $all[0];

                    if( $question_id > 0 ){
                        $iCG_url = wp_get_attachment_image_src( get_post_thumbnail_id($question_id), 'CG-image-size' );
                        $params = array(
                            'post'      => get_post( $question_id ),
                            'question_type' => get_post_meta( $question_id, '_question_type', true ),
                            'image'  => get_the_post_thumbnail( $question_id, 'CG-image-size', array('class' => 'CG-image-to-guess') ),
                            'image_url'  =>  $iCG_url[0],
                            'video_url' => get_post_meta( $question_id, '_video', true ),
                            'answers'   => get_post_meta( $question_id, '_answers', true ),
                            'status' => 'PLAYING',
                            'contest_id' => $contest_id,

                        );

                        if( $this->check_if_game_start( $contest_id ) === false ) {
                            //die( __FILE__ . ":" . __LINE__  );
                            $this->game_start_html( $contest_id );
                        }
                        else{

                             // id of session
                            $game_id = $this->use_question( $params );
                            $this->print_next_question_html( $params, $contest_id, $game_id );
                        }

                        /// feature on api as json ...
                    }

                    var_dump('<pre>',$question_id ,'</pre>'); echo __FILE__ . ":" . __LINE__;die . PHP_EOL;  
                }

                var_dump('<pre>',$all ,'</pre>'); echo __FILE__ . ":" . __LINE__;die . PHP_EOL;  
            }else{
                die("invalid contest id!");
            }
        }

        public function check_answer()
        {
            $params = array(
                'game_id' => isset($_REQUEST['game_id']) ? (int) $_REQUEST['game_id']: 0,
                'question_id' => isset($_REQUEST['question_id']) ? (int) $_REQUEST['question_id']: 0,
                'contest_id' => isset($_REQUEST['contest_id']) ? (int) $_REQUEST['contest_id']: 0,
                'answer' => isset($_REQUEST['answer']) ? $_REQUEST['answer']: "",
                'points' => isset($_REQUEST['points']) ? (int)$_REQUEST['points']: 0
            );

            $_SESSION['CG']['game']['total_points'] += $params['points'];

            if( $params['question_id'] == 0 ){
                die("hmm..");
            }

            $answers = get_post_meta( $params['question_id'], '_answers', true );
            $status = 'WRONG';
            if( count($answers) > 0 ){
                foreach ($answers as $answer) {
                    if( $params['answer'] == $answer['text'] && $answer['type'] == 'correct' ){
                        $status = 'CORRECT';
                    }
                }
            }


            CG()->db->update( 
                $this->db_name, 
                array( 
                    'answer_status' => $status, 
                    'points_nb'     => ( $status == "CORRECT" ? $params['points'] : 0 )
                ), 
                array( 
                    'game_id' => $params['game_id'],
                    'answer_status' => 'PLAYING'
                ), 
                array( 
                    '%s',
                    '%d'
                ), 
                array( 
                    '%d',
                    '%s'
                 ) 
            );
        }
    }
} 