<?php
/**
 * CG Main manager.
 *
 * @package CG
 * @since   1.0
 */
if ( ! function_exists( 'CG' ) ) {
	/**
	 * CG manager.
	 * @since 1.0
	 * @return CG
	 */
	function CG() {
		global $CG;

		return $CG;
	}
}

if ( ! function_exists( 'CG_Settings' ) ) {
	/**
	 * CG manager.
	 * @since 1.0
	 * @return CG_Settings
	 */
	function CG_Settings() {
		return new CG_Settings();
	}
}

if ( ! function_exists( 'CG_Social' ) ) {
	/**
	 * CG manager.
	 * @since 1.0
	 * @return CG_Social
	 */
	function CG_Social() {
		return new CG_Social();
	}
}

if ( ! function_exists( 'CG_Settings_Build_Options' ) ) {
	/**
	 * CG manager.
	 * @since 1.0
	 * @return CG_Settings
	 */
	function CG_Settings_Build_Options( $options=array(), $box_id='' ) {
		return CG_Settings()->build_options( $options, $box_id );
	}
}

/*
if ( ! function_exists( 'CG_Envato_Helper' ) ) {
	function CG_Envato_Helper() {
		return new CG_Envato_Helper();
	}
}*/

if ( ! function_exists( 'CG_Woocommerce' ) ) {
	/**
	 * CG manager.
	 * @since 1.0
	 * @return CG_Settings
	 */
	function CG_Woocommerce() {
		return new CG_Woocommerce();
	}
}

if ( ! function_exists( 'CG_Load_Options' ) ) {
	/**
	 * CG manager.
	 * @since 1.0
	 * @return CG_Settings
	 */
	function CG_Load_Options( $dir ) {
	    new CG_Settings(); // save settings first!
	    
		$options = array();
			
		// find if we have a options.php into the same folder
		$options_file = $dir . '/options.php';
		if( is_file($options_file) ){
			
			ob_start();
			require_once $options_file;
			
			$content = ob_get_contents();
			ob_clean();
 
			if( trim($content) != "" ){
				$options = json_decode( $content, true );
			}
		}
		return $options;
	}
}

if ( ! function_exists( 'CG_mapper' ) ) {
	/**
	 * Shorthand for CG Mapper.
	 * @since 1.0
	 * @return CG_Mapper
	 */
	function CG_mapper() {
		return CG()->mapper();
	}
}
if ( ! function_exists( 'CG_settings' ) ) {
	/**
	 * Shorthand for CG settings.
	 * @since 1.0
	 * @return CG_Settings
	 */
	function CG_settings() {
		return CG()->settings();
	}
}
if ( ! function_exists( 'CG_path_dir' ) ) {
	/**
	 * Get file/directory path in CG.
	 *
	 * @param string $name - path name
	 * @param string $file
	 *
	 * @since 1.0
	 * @return string
	 */
	function CG_path_dir( $name, $file = '' ) {
		return CG()->path( $name, $file );
	}
}
if ( ! function_exists( 'CG_upload_dir' ) ) {
	/**
	 * Temporary files upload dir;
	 * @since 1.0
	 * @return string
	 */
	function CG_upload_dir() {
		return CG()->uploadDir();
	}
}
if ( ! function_exists( 'CG_path_dir' ) ) {
	/**
	 * Get file/directory path in CG.
	 *
	 * @param string $name - path name
	 * @param string $file
	 *
	 * @since 4.2
	 * @return string
	 */
	function CG_path_dir( $name, $file = '' ) {
		return CG()->path( $name, $file );
	}
}
if ( ! function_exists( 'CG_post_param' ) ) {
	/**
	 * Get param value from $_POST if exists.
	 *
	 * @param $param
	 * @param $default
	 *
	 * @since 1.0
	 * @return null|string - null for undefined param.
	 */
	function CG_post_param( $param, $default = null ) {
		return isset( $_POST[ $param ] ) ? $_POST[ $param ] : $default;
	}
}
if ( ! function_exists( 'CG_get_param' ) ) {
	/**
	 * Get param value from $_GET if exists.
	 *
	 * @param $param
	 * @param $default
	 *
	 * @since 1.0
	 * @return null|string - null for undefined param.
	 */
	function CG_get_param( $param, $default = null ) {
		return isset( $_GET[ $param ] ) ? $_GET[ $param ] : $default;
	}
}
if ( ! function_exists( 'CG_request_param' ) ) {
	/**
	 * Get param value from $_REQUEST if exists.
	 *
	 * @param $param
	 * @param $default
	 *
	 * @since 4.4
	 * @return null|string - null for undefined param.
	 */
	function CG_request_param( $param, $default = null ) {
		return isset( $_REQUEST[ $param ] ) ? $_REQUEST[ $param ] : $default;
	}
}
if ( ! function_exists( 'CG_action' ) ) {
	/**
	 * Get CG special action param.
	 * @since 1.0
	 * @return string|null
	 */
	function CG_action() {
		$CG_action = 'dashboard';
		if ( isset( $_GET['CG_action'] ) ) {
			$CG_action = $_GET['CG_action'];
		} elseif ( isset( $_POST['CG_action'] ) ) {
			$CG_action = $_POST['CG_action'];
		}

		return $CG_action;
	}
}

if ( ! function_exists( 'CG_asset_url' ) ) {
	/**
	 * Get full url for assets.
	 *
	 * @param string $file
	 *
	 * @since 4.2
	 * @return string
	 */
	function CG_asset_url( $file ) {
		return CG()->assetUrl( $file );
	}
}

if ( ! function_exists( 'CG_templates_url' ) ) {
	/**
	 * Get full url for assets.
	 *
	 * @param string $file
	 *
	 * @since 4.2
	 * @return string
	 */
	function CG_templates_url( $file ) {
		return CG()->templatesUrl( $file );
	}
}

if ( ! function_exists( 'CG_locate_template' ) ) {
	function CG_locate_template( $template_name, $template_path = '', $default_path = '' ) 
	{
	    if ( ! $template_path ) {
	        $template_path = 'templates/';
	    }

	    if ( ! $default_path ) {
	        $default_path = CG()->path( 'TEMPLATES_DIR', '' );
	    }
 
	    // Look within passed path within the theme - this is priority.
	    $template = locate_template(
	        array(
	            trailingslashit( $template_path ) . $template_name,
	            $template_name
	        )
	    );

	    // Get default template/
	    if ( ! $template ) {
	        $template = $default_path . $template_name;
	    }

	    // Return what we found.
	    return apply_filters( 'CG_locate_template', $template, $template_name, $template_path );
	}
}


if ( ! function_exists( 'CG_Get_IP' ) ) {
	function CG_Get_IP() 
	{
		//Just get the headers if we can or else use the SERVER global
		if ( function_exists( 'apache_request_headers' ) ) {
			$headers = apache_request_headers();
		} else {
			$headers = $_SERVER;
		}
		//Get the forwarded IP if it exists
		if ( array_key_exists( 'X-Forwarded-For', $headers ) && filter_var( $headers['X-Forwarded-For'], FILTER_VALIDATE_IP, FILTER_FLAG_IPV4 ) ) {
			$the_ip = $headers['X-Forwarded-For'];
		} elseif ( array_key_exists( 'HTTP_X_FORWARDED_FOR', $headers ) && filter_var( $headers['HTTP_X_FORWARDED_FOR'], FILTER_VALIDATE_IP, FILTER_FLAG_IPV4 )
		) {
			$the_ip = $headers['HTTP_X_FORWARDED_FOR'];
		} else {
			$the_ip = filter_var( $_SERVER['REMOTE_ADDR'], FILTER_VALIDATE_IP, FILTER_FLAG_IPV4 );
		}
		return $the_ip;
	}
}

/**
 * Plugin name for CG_time_elapsed_string.
 *
 * @since 1.0
 * @return string
 */
if ( ! function_exists( 'CG_time_elapsed_string' ) ) {
	function CG_time_elapsed_string($ptime)
	{
	    $etime = time() - $ptime;
	
	    if ($etime < 1)
	    {
	        return '0 seconds';
	    }
	
	    $a = array( 365 * 24 * 60 * 60  =>  'year',
	                 30 * 24 * 60 * 60  =>  'month',
	                      24 * 60 * 60  =>  'day',
	                           60 * 60  =>  'hour',
	                                60  =>  'minute',
	                                 1  =>  'second'
	                );
	    $a_plural = array( 'year'   => 'years',
	                       'month'  => 'months',
	                       'day'    => 'days',
	                       'hour'   => 'hours',
	                       'minute' => 'minutes',
	                       'second' => 'seconds'
	                );
	
	    foreach ($a as $secs => $str)
	    {
	        $d = $etime / $secs;
	        if ($d >= 1)
	        {
	            $r = round($d);
	            return $r . ' ' . ($r > 1 ? $a_plural[$str] : $str) . ' ago';
	        }
	    }
	}
}


/**
 * Plugin name for CG.
 *
 * @since 1.0
 * @return string
 */
function CG_plugin_name() {
	return CG()->pluginName();
}