<?php 

/*
 * Define class CG_Template
 * Make sure you skip down to the end of this file, as there are a few
 * lines of code that are very important.
 */
!defined('ABSPATH') and exit;

if (class_exists('CG_Template') != true) {
	
	class CG_Template
	{
		/*
		 * Some required plugin information
		 */
		const VERSION = '1.0';
		
		public $post_type = '';
		public $cfg = array();
		public $template_directory = '';
		public $the_plugin = array();

		/*
		 * Required __construct() function that initalizes the CG_Template
		 */
		public function __construct( $the_plugin=array() )
		{

			$this->the_plugin = $the_plugin;

			$this->cfg['fonts']['Passion+One'] = 'https://fonts.googleapis.com/css?family=Passion+One:400,700,900&amp;subset=latin-ext';
			$this->cfg['fonts']['Poppins'] = 'https://fonts.googleapis.com/css?family=Poppins:300,400,500,600,700';
			$this->cfg['fonts']['Chewy'] = 'https://fonts.googleapis.com/css?family=Chewy';

			add_shortcode( 'contest', array( $this, 'contest' ) );
			add_shortcode( 'contest_list', array( $this, 'contest_list' ) );

			add_action( 'wp_ajax_' . ( $this->the_plugin->alias )  . '_ajax_action', array( $this, 'ajax_requests' ) );
			add_action( 'wp_ajax_nopriv_' . ( $this->the_plugin->alias )  . '_ajax_action', array( $this, 'ajax_requests' ) );

			add_filter('the_content', array( $this, 'load_contest_page_content') );
			
			add_action( 'wp_head', array( $this, 'contest_fb_og_meta' ) );
		}
		
		public function contest_fb_og_meta()
		{
			// global $post;
			
			// $pattern = get_shortcode_regex();
			// preg_match('/'.$pattern.'/s', $post->post_content, $shortcodes);
				
			//if ( is_array($shortcodes) && array_key_exists(2, $shortcodes) && $shortcodes[2] == 'contest' ) {
			if ( isset( $_REQUEST['term_id'] ) && trim($_REQUEST['term_id']) != '' ){
				$contest_id = $_REQUEST['term_id'];
				$term = get_term( $contest_id, 'contests' );

				if ( $term != null ) {
					$termMeta = get_term_meta($term->term_id);
					$image_id = $termMeta['contest-image-id'][0];
					$title = $term->name;
					$description = $term->description;
					$image_url = wp_get_attachment_image_src ( $image_id, 'large' );
					
					echo '<meta property="og:type" content="website" />';
					echo '<meta property="og:image" content="' . $image_url[0] . '"></meta>';
					echo '<meta property="og:description" content="' . $description . '" />';
					echo '<meta property="og:url" content="' . home_url( add_query_arg( null, null )) . '" />';
					echo '<meta property="og:title" content="' . $title . '" />';
				}
			}
		}

		public function load_styles_and_script()
		{
			// load frontend google fonts
			if( count($this->cfg['fonts']) > 0 ){
				foreach ($this->cfg['fonts'] as $font_key => $font_value) {
					wp_enqueue_style( CG()->alias . '-fonts-' . sanitize_title($font_key), $font_value, array() );
				}
			}

			wp_enqueue_style( '' . ( CG()->alias )  . '-font-awesome', 'http://maxcdn.bootstrapcdn.com/font-awesome/4.1.0/css/font-awesome.min.css?ver=4.4.2', array() );
			wp_enqueue_style( '' . ( CG()->alias )  . '-frontend_style', admin_url('admin-ajax.php?action=' . ( CG()->alias )  . '_ajax_action&sub_action=frontend_style'), array(), CG_VERSION );

			wp_enqueue_script( CG()->alias . '-charts-js', 'https://www.gstatic.com/charts/loader.js', array(), '1.0.0' );
			wp_enqueue_script( CG()->alias . '-main-game', CG_templates_url( 'js/game.class.js' ), array('jquery'), '1.0', true);
			wp_localize_script( CG()->alias . '-main-game', CG()->alias . '_Utils', array( 'ajaxurl' => admin_url( 'admin-ajax.php' ) ) );
		}

		public function load_contest_page_content ( $content ) {

			global $post;
			$atts = array();
			$shortcode = '';
			
			if (is_page($this->the_plugin->settings['generator_page'] ) && isset($_REQUEST['show_stats']) && $_REQUEST['show_stats'] == 'true' && isset($_REQUEST['term_id']) && $_REQUEST['term_id'] != 0 ) {
				$this->load_styles_and_script();
				echo '<div class="' . ( CG()->alias )  . '-all-wrapper">
							<div class="' . ( CG()->alias )  . '-wrapper">
								<div class="' . ( CG()->alias )  . '-body ' . ( CG()->alias )  . '-contest ' . ( CG()->alias )  . '-img">
									<div id="CG-contest-chart" data-showstatsforcontestid="' . $_REQUEST['term_id'] . '" >' . __('Loading...', 'CG') . '</div>
								</div>
							</div>
						</div>';
				
			}
			elseif( is_page($this->the_plugin->settings['generator_page'] ) && isset($_REQUEST['reset_contest']) && $_REQUEST['reset_contest'] == 'true' && isset($_REQUEST['term_id']) && $_REQUEST['term_id'] != 0) {
				$this->load_styles_and_script();
				echo '<div class="' . ( CG()->alias )  . '-all-wrapper">
							<div class="' . ( CG()->alias )  . '-wrapper">
								<div class="' . ( CG()->alias )  . '-body ' . ( CG()->alias )  . '-contest ' . ( CG()->alias )  . '-img">
									<div id="CG-reset-contest" data-reset_contest="' . $_REQUEST['term_id'] . '">' . __('Loading...', 'CG') . '</div>
								</div>
							</div>
						</div>';
			} 
			elseif (is_page($this->the_plugin->settings['generator_page'] ) && isset($_REQUEST['term_id']) && $_REQUEST['term_id'] != 0 ) {
				$atts['id'] = $_REQUEST['term_id'];
				echo $this->contest($atts);
			}
			else {
				$pattern = get_shortcode_regex();
				preg_match('/'.$pattern.'/s', $content, $shortcodes);
				$content = preg_replace('/'.$pattern.'/s', '', $content);
				echo $content;

				if (is_array($shortcodes) && array_key_exists(2, $shortcodes) && $shortcodes[2] == 'contest_list') {
					$shortcode = $shortcodes[0];
					do_shortcode($shortcode);
				}
					
				elseif (is_array($shortcodes) && array_key_exists(2, $shortcodes) && $shortcodes[2] == 'contest') {
				   $shortcode = $shortcodes[0];
				   echo do_shortcode($shortcode);
				}
			}	
		}
		
		public function contest( $atts )
		{
			
			global $post;

			$atts = shortcode_atts( array(
				'id'	=>	0,
				'continue' => 0
			), $atts, 'contest' );

			$cid = isset($_REQUEST['term_id']) ? (int) $_REQUEST['term_id'] : 0;
			if( $cid > 0 ){
				$atts['id'] = $cid;
			}

			$this->load_styles_and_script();

			echo '<div id="fb-root"></div><script>(function(d, s, id) {var js, fjs = d.getElementsByTagName(s)[0];if (d.getElementById(id)) return;js = d.createElement(s); js.id = id;js.src = \'https://connect.facebook.net/en_US/sdk.js#xfbml=1&version=v2.11\';fjs.parentNode.insertBefore(js, fjs);}(document, \'script\', \'facebook-jssdk\'));

				window.fbAsyncInit = function(){
						            FB.XFBML.parse();
						        };
			</script>';

			if( (int) $atts['id'] > 0 ){

				//if ( is_user_logged_in() ) {
					$html = array();
					$html[] = '<div class="' . ( CG()->alias )  . '-all-wrapper" data-continuecontest="' . ( var_export($atts['continue'], true) ) . '" data-contestid="' . ( $atts['id'] ) . '" >
								<div class="' . ( CG()->alias )  . '-wrapper">
									<div class="' . ( CG()->alias )  . '-body ' . ( CG()->alias )  . '-contest ' . ( CG()->alias )  . '-img">
										
									</div>
								</div>
							</div>';
				//} 
				//else {
					//return '<div class="' . ( CG()->alias )  . '-need-to-login">In order to Play this Contest you need to have an account and be logged in. Please <a href="' . ( wp_login_url( get_the_permalink( $post ) ) ) . '" title="Login">Login / Register</a> now!</div>';
				//}

				return implode( "", $html );
			} else {
				echo '<div class="' . ( CG()->alias )  . '-all-wrapper" data-continuecontest="0" data-contestid="0" >
								<div class="' . ( CG()->alias )  . '-wrapper">
									<div class="' . ( CG()->alias )  . '-body ' . ( CG()->alias )  . '-contest ' . ( CG()->alias )  . '-img">
										
									</div>
								</div>
							</div>';
			}
		}

		public function contest_list ( $atts ) {

			global $post;
			$continue = 0;

			//die( var_dump( "<pre>", $post  , "<pre>" ) . PHP_EOL .  __FILE__ . ":" . __LINE__  );  

			if ($post->ID != CG()->settings['generator_page'] ) {
				$continue = 1;
			}

			//get_query_var to get page id from url
			$page = ( get_query_var('paged') ) ? get_query_var('paged') : 1;
			 
			// number of tags to show per-page
			$per_page = CG()->settings['contests_per_page'];
			 
			//count total number of terms related to passed taxonomy
			
			$offset = ( $page - 1 ) * $per_page;
			$number = $per_page;

			$terms = get_terms( 'contests', array(
				'orderby'    => 'count',
				'hide_empty' => 0,
				'number' => $number,
				'offset' => $offset
			) );



			$number_of_series = count(get_terms('contests'));

			if ($terms) {
				// now run a query for each contest
				echo '<ul class="' . ( CG()->alias )  . '-contest-list">';

				foreach( $terms as $term ) {          
					 
					// output the post titles in a list
					echo '<li class="' . ( CG()->alias )  . '-contest-wrapper">';
					 
						if( isset( $term->term_id ) ){
							
							echo do_shortcode('[contest id=' . $term->term_id . ' continue=' . $continue . '][/contest]');
						} else {
							echo do_shortcode('[contest id=' . 0 . ' continue=' . $continue . '][/contest]');
						}
					echo '</li>';
					 
					// use reset postdata to restore orginal query
					wp_reset_postdata();

				}

				echo '</ul>';

				$big = 999999999;

				$total = ceil($number_of_series / $per_page);
				//die( var_dump( "<pre>", $total  , "<pre>" ) . PHP_EOL .  __FILE__ . ":" . __LINE__  ); 
 
				//your function for pagination or plugin you added for pagination
			   // die( var_dump( "<pre>", count($terms)  , "<pre>" ) . PHP_EOL .  __FILE__ . ":" . __LINE__  ); 
				echo 	'<div class="CG-pagination">' . paginate_links(array(
								'base' => str_replace($big, '%#%', esc_url(get_pagenum_link($big))),
								'format' => '?paged=%#%',
								'current' => max( 1, $page ),
								'prev_text'          => __('«'),
								'next_text'          => __('»'),
								'total' => $total // like 10 items per page
							)) .
							'<div class="CG-pagination-index">Page ' . max( 1, $page ) . ' of ' . $total .'</div>' .	 
						'</div>';
				 
			}
			else {
				echo '<ul class="' . ( CG()->alias )  . '-contest-list">';
				echo 	'<p>No contests created at the moment.</p>';
				echo '</ul>';
			}

		}


	    public function write_options_style( $buffer ) {

	    	$options = CG()->settings;

	    	$selectors = array(
	    		'.CG-all-wrapper h3'			=>	array(
	    												'color: ' . $options['main_heading_color'] . ';', 
	    												'border-color: ' . $options['main_heading_border'] . ';', 
	    												'font-size: ' . $options['main_heading_fontsize'] . ';',
	    												'font-family: "' . $options['main_heading_family'] . '";}'
	    											),

	    		'.CG-all-wrapper .CG-duration'	=>	array(
	    												'color: ' . $options['subheading_color'] . ';',
	    												'font-size: ' . $options['subheading_fontsize'] . ';',
	    												'font-family: "' . $options['subheading_family'] . '";}'
    												),
	    		'.CG-all-wrapper p'				=>	array(
	    												'color: ' . $options['description_color'] . ';',
	    												'font-size: ' . $options['button_fontsize'] . ';',
	    												'font-family: "' . $options['description_family'] . '";}'
	    											),
	    		'.CG-all-wrapper .CG-button'	=>	array(
		    											'background: ' . $options['button_background_color'] . ';',
	    												'font-size: ' . $options['button_fontsize'] . ';',
		    											'color: ' . $options['button_font_color'] . ';',
		    											'font-family: "' . $options['button_family'] . '";}'
		    										),
	    		'.CG-all-wrapper a.CG-button'	=>	array(
		    											'background: ' . $options['button_background_color'] . ';',
	    												'font-size: ' . $options['button_fontsize'] . ';',
		    											'color: ' . $options['button_font_color'] . ';',
		    											'font-family: "' . $options['button_family'] . '";}'
		    										),
	    		'.CG-all-wrapper .CG-body'		=>	array(
	    												'background: ' . $options['background_color'] . ';}'
	    											),
	    		'.CG-all-wrapper .CG-info-boxes .CG-info,
	    		.CG-all-wrapper .CG-info-boxes div.CG-remaining-questions,
	    		.CG-all-wrapper .CG-info-boxes div.CG-finished-questions,
	    		.CG-all-wrapper .CG-img .CG-media .CG-img-to-guess,
	    		input[type="checkbox"] + label:before, input[type="radio"] + label:before,
	    		input[type="checkbox"] + label:after, input[type="radio"] + label:after' =>	array(
	    												'border-color: ' . $options['main_heading_border'] . ';',
	    													'color: ' . $options['main_heading_border'] . ';'
	    											)

	    	
	    		
	    	);

	    	foreach ($selectors as $selector => $properties) {
	    		$buffer .= 'body ' . $selector . '{';
	    		foreach($properties as $property) {
		    		$buffer .= $property;
	    		}
	    	}

	    	return $buffer;
	    }

		public function framework_style()
		{
			$start = microtime(true);
	

			require CG()->path( 'HELPERS_DIR', '/scssphp/scss.inc.php' );
			$scss = new scssc();  
			$main_file = CG()->wp_filesystem->get_contents( CG()->path( 'TEMPLATES_DIR', '/scss/styles.scss' ) );
			if( !$main_file ){
				$main_file = file_get_contents( CG()->path( 'TEMPLATES_DIR', '/scss/styles.scss' ) );
			} 

			$files = array();
			if(preg_match_all('/@import (url\(\"?)?(url\()?(\")?(.*?)(?(1)\")+(?(2)\))+(?(3)\")/i', $main_file, $matches)){
					foreach ($matches[4] as $url) {
						if( file_exists( CG()->path( 'TEMPLATES_DIR',  "/scss/_" . $url . '.scss' ) ) ){ 
							$files[] = '_' . $url . '.scss';
						}
						if( file_exists( CG()->path( 'TEMPLATES_DIR', "/scss/" . $url . '.scss') ) ){
							$files[] = $url . '.scss';
						}
					}
			}
			
			$buffer = '';
			if( count($files) > 0 ){
				foreach ($files as $scss_file) {
					if( 0 ){ 
						$buffer .= "\n" .   "/****-------------------------------\n";
						$buffer .= "\n" .   " IN FILE: $scss_file \n";
						$buffer .= "\n" .   "------------------------------------\n";
						$buffer .= "\n***/\n";
					}

					$has_wrote = CG()->wp_filesystem->get_contents( CG()->path( 'TEMPLATES_DIR',  "/scss/" . $scss_file ) );
					if ( !$has_wrote ) {
						$has_wrote = file_get_contents( CG()->path( 'TEMPLATES_DIR', "/scss/" . $scss_file ) );
					}
					$buffer .= $has_wrote;
				}
			}
						
			$buffer = $scss->compile( $buffer );

			$time_elapsed_secs = microtime(true) - $start;

			// to be continued 

			$buffer = $this->write_options_style($buffer);

			$buffer .= "\n\n/*** Compile time: $time_elapsed_secs */";
			
			// Enable caching
			header('Cache-Control: public');

			// Expire in one day
			header('Expires: ' . gmdate('D, d M Y H:i:s', time() + 86400) . ' GMT');
			//header('Expires: ' . gmdate('D, d M Y H:i:s', time() + 1) . ' GMT');

			// Set the correct MIME type, because Apache won't set it for us
			header("Content-type: text/css");

			// Write everything out
			echo $buffer;
			
			die;
		}

		public function ajax_contest_stats() {
			$db_name = $this->the_plugin->db->prefix . 'contest_games';

			$contest_id = isset($_REQUEST['contest']) && (int)$_REQUEST['contest'] > 0 ? (int)$_REQUEST['contest'] : 0;
			if( $contest_id == 0 ){
				die("Cmon ...");
			}

			$played_users = CG()->db->get_results( CG()->db->prepare ("
				SELECT SUM(points_nb) as obtained_points, user_id
				FROM " . ( $db_name ) . "
				WHERE 1=1 
					AND contest_id = %d
				GROUP BY user_id 
			", $contest_id ), ARRAY_A );

			foreach ($played_users as $key => $value) {
				$user = get_user_by('id', $value['user_id']);
				$played_users[$key]['user_name'] = $user->display_name;	
				
			}

			die( json_encode(array(
				'status' => 'valid',
				'data' => $played_users
			))) ;
		}

		public function reset_contest() {
			if ( is_admin() && is_user_logged_in() ){
				$db_name = $this->the_plugin->db->prefix . 'contest_games';

				$contest_id = isset($_REQUEST['contest']) && (int)$_REQUEST['contest'] > 0 ? (int)$_REQUEST['contest'] : 0;
				if( $contest_id == 0 ){
					die("Cmon ...");
				}

				$contest = CG()->db->query( CG()->db->prepare ("
						DELETE
						FROM " . ( $db_name ) . "
						WHERE 1=1 
							AND contest_id = %d
					", $contest_id ), ARRAY_A );

				if ( ((int) $contest) > 0 ) {
					die( json_encode(array(
						'status' => 'valid',
						'data' => 'The Contest has been successfully reset!'
					))) ;
				}
				else {
					die( json_encode(array(
						'status' => 'invalid'
					)));
				}
			}
			else {
				die( json_encode(array(
						'status' => 'invalid',
						'data' => 'You are not authorized for this!'
					)));
			}
			

		}

		public function ajax_requests()
		{
			$action = isset($_REQUEST['sub_action']) ? $_REQUEST['sub_action'] : 'none';
			$valid_actions = array( 'frontend_style', 'next-question', 'start-contest','check-answer', 'contest-chart', 'reset-contest', 'continue-contest');

			if( in_array( $action, $valid_actions ) ){
				if( $action == 'frontend_style' ){
					$this->framework_style();   
				}

				if( $action == 'next-question' ){

					$contest_id = isset($_REQUEST['contest_id']) ? (int)$_REQUEST['contest_id'] : 0 ;

					CG()->game->get_next_question( $contest_id );
				}

				if( $action == 'start-contest' ){

					$contest_id = isset($_REQUEST['contest_id']) ? (int)$_REQUEST['contest_id'] : 0 ;

					CG()->game->start_contest( $contest_id );  
				}

				if( $action == 'check-answer' ){

					CG()->game->check_answer();  
				}

				if ( $action == 'contest-chart') {
					$this->ajax_contest_stats();
				}

				if ( $action == 'reset-contest') {
					$this->reset_contest();
				}

				if( $action == 'continue-contest' ){

					$contest_id = isset($_REQUEST['contest_id']) ? (int)$_REQUEST['contest_id'] : 0 ;

					CG()->game->continue_contest( $contest_id );  
				}

			}else{
				die( "hmm.. " );
			} 
		}
	}
}