/*
Document   :  CGContests
Author     :  Alexandru Topala, Andrei Dinca, AA-Team http://themeforest.net/user/AA-Team
*/
// Initialization and events code for the app
CGContests = (function ($) {
    "use strict";

    // public
    var debug_level = 0;
    var maincontainer = null;

	// init function, autoload
	(function init() {
		// load the triggers
		$(document).ready(function(){

			maincontainer = $(".CG-answers-wrapper");

			triggers();

			contest_fields_validations();

			question_fields_validations();

		    // taxonomy image upload
		    ct_media_upload();

			// taxonomy datepicker
			$( 'input[name="term_meta[start_game_date]"]' ).datepicker();
			$( 'input[name="term_meta[end_game_date]"]' ).datepicker();

		});
	})();
	
	function create_new_row()
	{
		var parent = maincontainer.find("ul"),
			new_row = parent.find("li").eq(0).clone();

		new_row.find("input").val('');
		new_row.find("select").val('wrong');

		parent.append( new_row );
	}

	function triggers()
	{
		maincontainer.find("ul").sortable({
			containment: "parent",
			handle: ".CG-drag-ans"
		});

		maincontainer.on('click', '#CG-add-new-row', function(e){
			e.preventDefault();

			create_new_row();
		});

		maincontainer.on('click', '.CG-delete-btn', function(e){
			e.preventDefault();

			if( confirm("Are you sure you want to delete this?") ){
				$(this).parents('li').eq(0).remove();
			}
		});
	}

	function question_fields_validations() {

		if ($('.CG-video-to-guess-wrapper').length > 0) {
			var validVideoURL, validAnswers, validQuestionImage;

			function checkVideo ( that ) {
				
				if($('select[name="CG[questionType]"]').find("option:selected").val() == 'video' ) {

					if ( that == null ) {
						that = $('input[name="CG[video][url][]"]');
					}

					var videoRegEx = new RegExp('^(https?\:\/\/)?((www\.)?youtube\.com|youtu\.?be)\/.+$');

					if ( !videoRegEx.test(that.val()) ) {
						validVideoURL = false;
						if ( that.parent().find('.CG-field-validation').length == 0) {
							that.parent().append('<div class="CG-field-validation">URL should be of type "www.youtube.com/watch?v=ewoiq0-312" or "youtube.com/watch?v=ewoiq0-312"</div>');
						} 
						else {
							that.parent().find('.CG-field-validation').text('URL should be of type "www.youtube.com/watch?v=ewoiq0-312" or "youtube.com/watch?v=ewoiq0-312"');
						}
					} 
					else {
						if ( that.parent().find('.CG-field-validation').length > 0) {
							that.parent().find('.CG-field-validation').remove();
						}
						validVideoURL = true;
					}
				} else {
					validVideoURL = true;
				}

			}

			function checkAnswers () {
				var that;

				$('input[name="CG[answer][text][]"]').each(function() {
					that = $(this);

				if ( that.val().trim() == ''  ) {
					validAnswers = false;

					if ( that.parent().find('.CG-field-validation').length == 0) {
						that.parent().append('<div class="CG-field-validation">Field should not be empty</div>');
					} 
					else {
						that.parent().find('.CG-field-validation').text('Field should not be empty');
					}
				} 
				else {
					if ( that.parent().find('.CG-field-validation').length > 0) {
						that.parent().find('.CG-field-validation').remove();
					}
					validAnswers = true;
				}

				});
				
			}

			function checkQuestionImage () {
				var that;

				that = $('select[name="CG[questionType]"]'); 

				that.find("option:selected");

				if(that.val() == 'image' && $('a#set-post-thumbnail img').length == 0) {
					validQuestionImage = false;


					if ( that.parent().parent().find('.CG-field-validation').length == 0) {
						that.parent().parent().append('<div class="CG-field-validation">Then please insert a featured image.</div>');
						
					} 
					else {
						that.parent().parent().find('.CG-field-validation').text('Then please insert a featured image.');
					}
				} 
				else {
					if ( that.parent().parent().find('.CG-field-validation').length > 0) {
						that.parent().parent().find('.CG-field-validation').remove();
					}
					validQuestionImage = true;

				}
    					
    			
			}

			$('select[name="CG[questionType]"]').on('change', function(){
				checkQuestionImage();
			});

			$(document).ajaxComplete(function (event, xhr, settings) {
		        if (typeof settings.data === 'string' && /action=get-post-thumbnail-html/.test(settings.data) && xhr.responseJSON && typeof xhr.responseJSON.data === 'string') {
		            checkQuestionImage();
		       	}
		    });

			$('input[name="CG[video][url][]"]').on('change', function(){
				checkVideo( $(this) );
			});

			$('input[name="CG[answer][text][]"]').on('change', function(){
				checkAnswers();
			});

			// Submit if ok
			$('form#post').on('submit', function(e) {
				checkQuestionImage();
				checkVideo();
				checkAnswers();

				if (!validVideoURL || !validAnswers || !validQuestionImage) {
					return false;
				} 

			});
		}	
	}

	function contest_fields_validations() {

		var validStartDate		=		false,
			validEndDate		=		false,
			validUnblurSeconds	=		false,
			validMaxPointsNb	=		false,
			validImg			=		false;

		function checkStartGameDate( that ) {

			if ( that == null ) {
				that = $('input[name="term_meta[start_game_date]"]');
			}

			var DateFromValue 	= 	new Date(that.val());
			var DateToValue 	= 	new Date($('input[name="term_meta[end_game_date]"]').val());

			if ( (DateFromValue > DateToValue) || that.val() == '') {
				if ( that.parent().find('.CG-field-validation').length == 0) {
					that.parent().append('<div class="CG-field-validation">Start date must be sooner than end date</div>');
				} 
				else {
					that.parent().find('.CG-field-validation').text('Start date must be sooner than end date');
				}
			} 
			else {
				if ( that.parent().find('.CG-field-validation').length > 0) {
					that.parent().find('.CG-field-validation').remove();
				}
				validEndDate = true;
			}
		}

		function checkEndGameDate( that ) {

			if ( that == null ) {
				that = $('input[name="term_meta[end_game_date]"]');
			}

			var DateToValue 	= 	new Date(that.val());
			var DateFromValue	= 	new Date($('input[name="term_meta[start_game_date]"]').val());

			console.log(DateToValue + ' ' + DateFromValue );

			if ( (DateToValue < DateFromValue) || $('input[name="term_meta[end_game_date]"]').val() == '') {
				if ( that.parent().find('.CG-field-validation').length == 0) {
					that.parent().append('<div class="CG-field-validation">End date must be later than start date</div>');
				} 
				else {
					that.parent().find('.CG-field-validation').text('End date must be later than start date');
				}
			} 
			else {
				if ( that.parent().find('.CG-field-validation').length > 0) {
					that.parent().find('.CG-field-validation').remove();
				}
				validStartDate = true;
			}
		}

		function checkImage( ) {

			var that = $('#contest-image-wrapper');

			if ( that.find('img').length == 0 ) {

				if ( that.closest('td').find('.CG-field-validation').length == 0) {

					that.closest('td').append('<div class="CG-field-validation">Please insert an image</div>');
				} 
				else {
					that.closest('td').find('.CG-field-validation').text('Please insert an image');
				}
			} 
			else {
				if ( that.closest('td').find('.CG-field-validation').length > 0) {
					that.closest('td').find('.CG-field-validation').remove();
				}
				validImg = true;
			}
		}

		function checkUnblurSeconds( that ) {

			if ( that == null ) {
				that = $('input[name="term_meta[question_unblur_seconds]"]');
			}

			if ( that.val() == '' ) {
				if ( that.parent().find('.CG-field-validation').length == 0) {
					that.parent().append('<div class="CG-field-validation">Please set the number of seconds</div>');
				} 
				else {
					that.parent().find('.CG-field-validation').text('Please set the number of seconds');
				}
			} 
			else if ( !that.val().match(/^\d+$/) ) {
				if ( that.parent().find('.CG-field-validation').length == 0) {
					that.parent().append('<div class="CG-field-validation">Only numbers accepted</div>');
				} 
				else {
					that.parent().find('.CG-field-validation').text('Only numbers accepted');
				}
			} 
			else {
				if ( that.parent().find('.CG-field-validation').length > 0) {
					that.parent().find('.CG-field-validation').remove();
				}
				validUnblurSeconds = true;
			}

		}

		function checkMaxPointsNb( that ) {

			if ( that == null ) {
				that = $('input[name="term_meta[max_points_nb]"]');
			}

			if ( that.val() == '' ) {
				if ( that.parent().find('.CG-field-validation').length == 0) {
					that.parent().append('<div class="CG-field-validation">Please set the number of points</div>');
				} 
				else {
					that.parent().find('.CG-field-validation').text('Please set the number of points');
				}
			} 
			else if ( !that.val().match(/^\d+$/) ) {
				if ( that.parent().find('.CG-field-validation').length == 0) {
					that.parent().append('<div class="CG-field-validation">Only numbers accepted</div>');
				} 
				else {
					that.parent().find('.CG-field-validation').text('Only numbers accepted');
				}
			} 
			else {
				if ( that.parent().find('.CG-field-validation').length > 0) {
					that.parent().find('.CG-field-validation').remove();
				}
				validMaxPointsNb = true;
			}

		}

		$('input[name="term_meta[question_unblur_seconds]"]').on('change', function(){
			checkUnblurSeconds( $(this) );
		});

		$('input[name="term_meta[max_points_nb]"]').on('change', function(){
			checkMaxPointsNb( $(this) );
		});

		$('input[name="term_meta[start_game_date]"]').on('change', function(){
			checkStartGameDate( $(this) );
		});

		$('input[name="term_meta[end_game_date]"]').on('change', function(){
			checkEndGameDate( $(this) );
		});

		// Submit if ok
		$('body.taxonomy-contests #edittag').on('submit', function(e){

			checkEndGameDate();
			checkStartGameDate();
			checkImage();
			checkUnblurSeconds();
			checkMaxPointsNb();

			if (!validStartDate || !validEndDate || !validImg || !validUnblurSeconds || !validMaxPointsNb) {
				return false;
			} 
		});

		$('body.taxonomy-contests').each(function(){
			var that 	= $(this),
				input 	= that.find('input[name="contest-image-id"]');

			function do_not_allow_no_img()
			{

				var has_image 	= false,
					attachment 	= input.val(),
					btn_remove	= $('#ct_tax_media_remove'),
					btn_submit 	= that.find('#addtag input[type="submit"]');

				if( parseInt(attachment) > 0 ){
					has_image = true;
				}

				if( has_image == false ){
					btn_submit.attr('disabled', 'disabled');
					btn_remove.hide();
				}else{
					btn_remove.show();
					btn_submit.removeAttr('disabled');
				}
			}

			do_not_allow_no_img();
			input.bind("checkIfNoImg", function(){
				do_not_allow_no_img();
				checkImage();
			});

		});
	}

	function ct_media_upload() {

		$('.CG-img-upload-box-wrapper').each(function(){

			var that			= $(this),
				frame 			= null,
				addImgLink 		= that.find('#ct_tax_media_button'),
				delImgLink 		= that.find( '#ct_tax_media_remove' ),
				imgContainer 	= that.find( '#contest-image-wrapper' ),
				imgIdInput 		= that.find( '#contest-image-id' );

			addImgLink.on( 'click', function( event ){
    
				event.preventDefault();

				// If the media frame already exists, reopen it.

				if ( frame ) {
					frame.open();
					return;
				}

				// Create a new media frame
				frame = wp.media({
					title: 'Select or Upload Brand logo',
					button: {
						text: 'Use this image'
					},
					multiple: false  // Set to true to allow multiple files to be selected
				});

				// When an image is selected in the media frame...
				frame.on( 'select', function() {

					// Get media attachment details from the frame state
					var attachment = frame.state().get('selection').first().toJSON();

					var img_src = attachment.sizes.thumbnail.url;
					if( typeof(img_src) == undefined ){
						img_src = attachment.sizes.full.url;
					}
					// Send the attachment URL to our custom image input field.
					imgContainer.html( '<img src="' + img_src + '" alt="" style="max-width:100%;"/>' );

					// Send the attachment id to our hidden input
					imgIdInput.val( attachment.id );

					imgIdInput.trigger( 'checkIfNoImg' );

					// Hide the add image link
					addImgLink.addClass( 'hidden' );

					// Unhide the remove image link
					delImgLink.removeClass( 'hidden' );
				});

				// Finally, open the modal on click
				frame.open();
			});

			delImgLink.on( 'click', function( event ){

				event.preventDefault();

				// Clear out the preview image
				imgContainer.html( '' );

				// Un-hide the add image link
				addImgLink.removeClass( 'hidden' );

				// Hide the delete image link
				delImgLink.addClass( 'hidden' );

				// Delete the image id from the hidden input
				imgIdInput.val( '' );

				imgIdInput.trigger( 'checkIfNoImg' );

			});
		})
	}

	// external usage
	return {
	}
})(jQuery);