<?php
/**
 * memes post type class
 * =====================
 *
 * @author		AA-Team
 * @version		1.0
 * @access 		public
 * @return 		void
 */
!defined('ABSPATH') and exit;
if (class_exists('CGContests') != true) {
	class CGContests
	{
		/*
		* Some required plugin information
		*/
		const VERSION = '1.0';

		/*
		* Store some helpers config
		*/
		public $the_plugin = null;

		public $_settings = array();

		static protected $_instance;

		public function __construct()
		{
			$this->the_plugin = $GLOBALS['CG'];

			add_action( "init", array( $this, 'init_post_type' ) );

			add_action( 'admin_head', array( $this, 'load_extra_styles_admin' ) );

			add_action( 'wp_ajax_CG_get_user_chart', array( $this, 'ajax_user_contests_stats' ) );
		}

		public function load_extra_styles_admin()
		{
			$screen = get_current_screen();

			if(
				isset( $screen->post_type ) &&
				trim( $screen->post_type ) == 'question'
			) {
				wp_enqueue_style( 'admin-contests-style', $this->the_plugin->cfg["CURRENT_PT_URL"] . 'assets/style.css' );
				wp_enqueue_style( 'font-awesome', 'https://maxcdn.bootstrapcdn.com/font-awesome/4.4.0/css/font-awesome.min.css' );
				wp_enqueue_style( 'jquery-ui-core', $this->the_plugin->cfg["CURRENT_PT_URL"] . '/assets/jquery-ui.min.css' );
				wp_enqueue_style( 'jquery-ui-theme', $this->the_plugin->cfg["CURRENT_PT_URL"] . '/assets/jquery-ui.theme.min.css' );

				wp_enqueue_script( 'CG_templates_app', $this->the_plugin->cfg["CURRENT_PT_URL"] . 'assets/app.class.js', array('jquery-ui-datepicker'), '1.0.0', true );

				wp_enqueue_script('jquery-ui-core');
				wp_enqueue_script('jquery-ui-sortable');
				wp_enqueue_script('jquery-ui-datepicker');
			}
		}

		/**
		* Singleton pattern
		*
		* @return CGContests Singleton instance
		*/
		static public function getInstance()
		{
			if (!self::$_instance) {
				self::$_instance = new self;
			}

			return self::$_instance;
		}

		public function init_post_type()
		{
			// get label
			$labels = array(
				'name' 					=> __('Questions', 'CG'),
				'singular_name' 		=> __('question', 'CG'),
				'add_new' 				=> __('Add new question', 'CG'),
				'add_new_item' 			=> __('Add new question', 'CG'),
				'edit_item'			 	=> __('Edit question', 'CG'),
				'new_item' 				=> __('New question', 'CG'),
				'view_item' 			=> __('View question', 'CG'),
				'search_items' 			=> __('Search into Questions', 'CG'),
				'not_found' 			=> __('No Questions found', 'CG'),
				'not_found_in_trash' 	=> __('No Questions in trash', 'CG')
			);

			// start formationg arguments
			$args = array(
				'labels' => $labels,
				'public' => false,
				'publicly_queryable' => false,
				'show_ui' => true,
				'has_archive' => false,
				'query_var' => true,
				'rewrite' => false,
				'menu_icon' => CG_asset_url( 'images/icon.png' ),
				'capability_type' => 'post',
				'show_in_menu' => true,
				'supports' => array( 'title', 'thumbnail', 'editor' )
			);

			register_post_type( 'question', $args );
			remove_post_type_support( 'question', 'editor' );
			
			
			// add taxonomies for this post type
			$this->init_taxonomies();
			

			// add meta boxes to "memes" post type
			add_action('admin_menu', array($this, 'add_to_menu_metabox'));

			add_action( 'save_post', array( $this, 'save_post' ), 10, 3 );

			add_image_size( 'CG-image-size', 300, 300, true );
		}

	  

		// Initialize New Taxonomy Labels for the questions custom post type
		public function init_taxonomies()
		{
			$labels = array(
				'name' 				=> __( 'Contests', 'CG' ),
				'singular_name' 	=> __( 'Contest', 'CG' ),
				'search_items' 		=> __( 'Search Contest Types', 'CG' ),
				'all_items' 		=> __( 'All Contest Types', 'CG' ),
				'parent_item' 		=> __( 'Parent Contest Types', 'CG' ),
				'parent_item_colon' => __( 'Parent Contest Types:', 'CG' ),
				'edit_item' 		=> __( 'Edit Contest Types', 'CG' ),
				'update_item' 		=> __( 'Update Contest Type', 'CG' ),
				'add_new_item' 		=> __( 'Add New Contest Type', 'CG' ),
				'new_item_name' 	=> __( 'New Contest Type', 'CG' ),
			);

			// register taxonomy to hold our contests
			register_taxonomy(
				'contests',
				array('question'),
				array(
					'public' => true,
					'hierarchical' => true,
					'publicly_queryable' => true,
					'query_var' => true,
					'show_in_nav_menus' => true,
					'labels' => $labels,
					'show_tagcloud' => false
				)
			);

			add_action( 'contests_add_form_fields', array( $this, 'add_new_meta_field' ), 10, 2 );
			add_action( 'contests_edit_form_fields', array( $this, 'taxonomy_edit_meta_field' ), 10, 2 );

			add_action( 'edited_contests', array( $this, 'save_taxonomy_custom_meta' ), 10, 2 );
			add_action( 'create_contests', array( $this, 'save_taxonomy_custom_meta' ), 10, 2 );

			add_action( 'show_user_profile', array( $this, 'extra_user_profile_fields'), 10, 2 );
			add_action( 'edit_user_profile', array( $this, 'extra_user_profile_fields'), 10, 2 );

			add_action( 'admin_enqueue_scripts', array( $this, 'load_media' ) );

			add_filter( 'manage_edit-contests_columns',  array( $this, 'add_taxonomy_columns' ) );
			add_filter( 'manage_contests_custom_column', array( $this, 'contests_type_columns' ), 1, 3 );
		}

		public function ajax_user_contests_stats()
		{
			$db_name = $this->the_plugin->db->prefix . 'contest_games';

			$user_id = isset($_REQUEST['user']) && (int)$_REQUEST['user'] > 0 ? (int)$_REQUEST['user'] : 0;
			if( $user_id == 0 ){
				die("Cmon ...");
			}

			$played_contests = CG()->db->get_results( CG()->db->prepare ("
				SELECT SUM(points_nb) as obtained_points, contest_id
				FROM " . ( $db_name ) . "
				WHERE 1=1 
					AND user_id = %d
				GROUP BY contest_id 
			", $user_id ), ARRAY_A );

			$contests = get_terms( 'contests', array(
				'orderby'    => 'count',
				'hide_empty' => 0
			) );

			foreach ($played_contests as $key => $value) {
				foreach ($contests as $contest) {
					if ($contest->term_id == $value['contest_id']) {
						$played_contests[$key]['contest_name'] = $contest->name;
					}
				}
			}

			die( json_encode(array(
				'status' => 'valid',
				'data' => $played_contests
			))) ;
		}

		public function user_contests_stats ( $user = null )
		{
			echo '<h3>' . __("Contest Generator Statistics", "CG") . '</h3>';
			echo '<div id="CG-user-chart" data-user="' . ( $user->ID ) . '">' . __('Loading...', 'CG') . '</div>';
		}

		public function extra_user_profile_fields( $user ) {
			$this->user_contests_stats($user);
		}

		public function add_taxonomy_columns( $original_columns ) {
			$new_columns = $original_columns;
			//array_splice( $new_columns, 1 );
			$new_columns['contest_view'] = 'View Contest';
			$new_columns['contest_stats'] = 'Statistics';
			$new_columns['reset_contest'] = 'Reset Contest';
			return array_merge( $new_columns, $original_columns );
		}

		public function contests_type_columns( $content,$column_name,$term_id ) {
			switch ($column_name) {
				case 'contest_view':
					$content = '<a href="' .  add_query_arg( 'term_id', $term_id, esc_url(get_permalink($this->the_plugin->settings['generator_page'] ))) . '">' . __('See The Contest', 'CG') .'</a>';

					break;
				case 'contest_stats':
					$arr_params = array ( 'term_id' => $term_id, 'show_stats' => 'true' );
					$content = '<a href="' .  add_query_arg( $arr_params, esc_url(get_permalink($this->the_plugin->settings['generator_page'] ))) . '">' . __('Check Contest Stats', 'CG') .'</a>';
					break;
				case 'reset_contest':
					$arr_params = array ( 'term_id' => $term_id, 'reset_contest' => 'true' );
					$content = '<a href="' .  add_query_arg( $arr_params, esc_url(get_permalink($this->the_plugin->settings['generator_page'] ))) . '">' . __('Reset Contest Plays', 'CG') .'</a>';
					break;
				default:
					break;
			}
			return $content;
		}

		public function load_media() {
			wp_enqueue_media();
		}

		public function add_new_meta_field()
		{
			// this will add the custom meta field to the add new term page
			?>
				<div class="form-field form-required">
					<label for="term_meta[question_unblur_seconds]"><?php _e( 'Question unblur seconds', 'CG' ); ?></label>
					<input type="text" name="term_meta[question_unblur_seconds]" id="term_meta[question_unblur_seconds]" value="">
					<p class="description"><?php _e( 'Setup in how many seconds the image will unblur itself','CG' ); ?></p>
				</div>

				<div class="form-field form-required">
					<label for="term_meta[max_points_nb]"><?php _e( 'Question number of max points', 'CG' ); ?></label>
					<input type="text" name="term_meta[max_points_nb]" id="term_meta[max_points_nb]" value="">
					<p class="description"><?php _e( 'Maximum points for each question','CG' ); ?></p>
				</div>

				<div class="form-field form-required">
					<label for="term_meta[start_game_button_text]"><?php _e( 'Start Game Button Text', 'CG' ); ?></label>
					<input type="text" name="term_meta[start_game_button_text]" id="term_meta[start_game_button_text]" value="">
					<p class="description"><?php _e( 'Custom Start game button text','CG' ); ?></p>
				</div>

				<div class="form-field form-required">
					<label for="term_meta[continue_game_button_text]"><?php _e( 'Continue Game Button Text', 'CG' ); ?></label>
					<input type="text" name="term_meta[continue_game_button_text]" id="term_meta[continue_game_button_text]" value="">
					<p class="description"><?php _e( 'Custom Continue game button text','CG' ); ?></p>
				</div>

				<div class="form-field term-group">
					<div class="CG-img-upload-box-wrapper">
						<label for="contest-image-id"><?php _e('Custom Contest Image', 'hero-theme'); ?></label>
						<input type="hidden" id="contest-image-id" name="contest-image-id" class="custom_media_url" value="">
						<div id="contest-image-wrapper"></div>
						<p>
						<input type="button" class="button button-secondary ct_tax_media_button" id="ct_tax_media_button" name="ct_tax_media_button" value="<?php _e( 'Add Image', 'CG' ); ?>" />
						<input type="button" class="button button-secondary ct_tax_media_remove" id="ct_tax_media_remove" name="ct_tax_media_remove" value="<?php _e( 'Remove Image', 'CG' ); ?>" />
						</p>
					</div>
				</div>

				<div class="form-field form-required">
					<label for="term_meta[start_game_date]"><?php _e( 'Setup the Date for the game to start', 'CG' ); ?></label>
					<input type="text" name="term_meta[start_game_date]" id="term_meta[start_game_date]" value="">
					<p class="description"><?php _e( 'Setup the Date for the game to start','CG' ); ?></p>
				</div>

				<div class="form-field form-required">
					<label for="term_meta[end_game_date]"><?php _e( 'Setup the Date when the game will end', 'CG' ); ?></label>
					<input type="text" name="term_meta[end_game_date]" id="term_meta[end_game_date]" value="">
					<p class="description"><?php _e( 'Setup the Date when the game will end. If the date is passed, the game will become unavailable','CG' ); ?></p>
				</div>

				<div class="form-field form-required">
					<label for="term_meta[finish_page_title]"><?php _e( 'Setup Finish Page Title', 'CG' ); ?></label>
					<input type="text" name="term_meta[finish_page_title]" id="term_meta[finish_page_title]" value="">
					<p class="description"><?php _e( 'Custom Finish page title','CG' ); ?></p>
				</div>

				<div class="form-field">
					<label for="term_meta[finish_page_extra_text]"><?php _e( 'Setup Finish Page Extra Text', 'CG' ); ?></label>
					<input type="text" name="term_meta[finish_page_extra_text]" id="term_meta[finish_page_extra_text]" value="">
					<p class="description"><?php _e( 'Custom Finish Page Extra Text','CG' ); ?></p>
				</div>

			<?php
		}

		 function taxonomy_edit_meta_field($term) {

			// put the term ID into a variable
			$t_id = $term->term_id;
			// retrieve the existing value(s) for this meta field. This returns an array
			$term_meta = get_term_meta( $t_id ); 

			?>
			<tr class="form-field form-required">
			<th scope="row" valign="top"><label for="term_meta[question_unblur_seconds]"><?php _e( 'Question unblur seconds', 'CG' ); ?></label></th>
				<td>
					<input type="text" name="term_meta[question_unblur_seconds]" id="term_meta[question_unblur_seconds]" value="<?php echo esc_attr( $term_meta['question_unblur_seconds'][0] ) ? esc_attr( $term_meta['question_unblur_seconds'][0] ) : ''; ?>">
					<p class="description"><?php _e( 'Setup in how many seconds the image will unblur itself','CG' ); ?></p>
				</td>
			</tr>

			<tr class="form-field form-required">
			<th scope="row" valign="top"><label for="term_meta[max_points_nb]"><?php _e( 'Question max points', 'CG' ); ?></label></th>
				<td>
					<input type="text" name="term_meta[max_points_nb]" id="term_meta[max_points_nb]" value="<?php echo esc_attr( $term_meta['max_points_nb'][0] ) ? esc_attr( $term_meta['max_points_nb'][0] ) : ''; ?>">
					<p class="description"><?php _e( 'Maximum points for each question','CG' ); ?></p>
				</td>
			</tr>

			<tr class="form-field form-required">
				<th scope="row" valign="top"><label for="term_meta[start_game_button_text]"><?php _e( 'Start game button text', 'CG' ); ?></label></th>
				<td>
					<input type="text" name="term_meta[start_game_button_text]" id="term_meta[start_game_button_text]" value="<?php echo esc_attr( $term_meta['question_unblur_seconds'][0] ) ? esc_attr( $term_meta['start_game_button_text'][0] ) : ''; ?>">
					<p class="description"><?php _e( 'Custom Start game button text','CG' ); ?></p>
				</td>
			</tr>

			<tr class="form-field form-required">
				<th scope="row" valign="top"><label for="term_meta[continue_game_button_text]"><?php _e( 'Continue game button text', 'CG' ); ?></label></th>
				<td>
					<input type="text" name="term_meta[continue_game_button_text]" id="term_meta[continue_game_button_text]" value="<?php echo esc_attr( $term_meta['question_unblur_seconds'][0] ) ? esc_attr( $term_meta['continue_game_button_text'][0] ) : ''; ?>">
					<p class="description"><?php _e( 'Custom Continue game button text','CG' ); ?></p>
				</td>
			</tr>

			<tr class="form-field form-required term-group-wrap">
				<th scope="row">
					<label for="contest-image-id"><?php _e( 'Custom Contest Image', 'hero-theme' ); ?></label>
				</th>
				<td>
					<div class="CG-img-upload-box-wrapper">
						<?php $image_id = get_term_meta ( $term -> term_id, 'contest-image-id', true ); ?>
						<input type="hidden" id="contest-image-id" name="contest-image-id" value="<?php echo $image_id; ?>">
						<div id="contest-image-wrapper">
							<?php if ( $image_id ) { ?>
								<?php echo wp_get_attachment_image ( $image_id, 'thumbnail' ); ?>
							<?php } ?>
						</div>
						<p>
							<input type="button" class="button button-secondary ct_tax_media_button" id="ct_tax_media_button" name="ct_tax_media_button" value="<?php _e( 'Add Image', 'CG' ); ?>" />
							<input type="button" class="button button-secondary ct_tax_media_remove" id="ct_tax_media_remove" name="ct_tax_media_remove" value="<?php _e( 'Remove Image', 'CG' ); ?>" />
						</p>
					</div>
				</td>
			</tr>

			<tr class="form-field form-required">
				<th scope="row" valign="top"><label for="term_meta[start_game_date]"><?php _e( 'Date the game will start', 'CG' ); ?></label></th>
				<td>
					<input type="text" name="term_meta[start_game_date]" id="term_meta[start_game_date]" value="<?php echo esc_attr( $term_meta['start_game_date'][0] ) ? esc_attr( $term_meta['start_game_date'][0] ) : ''; ?>">
					<p class="description"><?php _e( 'Setup the Date for the game to start','CG' ); ?></p>
				</td>
			</tr>

			<tr class="form-field form-required">
				<th scope="row" valign="top"><label for="term_meta[end_game_date]"><?php _e( 'Date the game will end', 'CG' ); ?></label></th>
				<td>
					<input type="text" name="term_meta[end_game_date]" id="term_meta[end_game_date]" value="<?php echo esc_attr( $term_meta['end_game_date'][0] ) ? esc_attr( $term_meta['end_game_date'][0] ) : ''; ?>">
					<p class="description"><?php _e( 'Setup the Date for the game to end','CG' ); ?></p>
				</td>
			</tr>

			<tr class="form-field form-required">
				<th scope="row" valign="top"><label for="term_meta[finish_page_title]"><?php _e( 'Finish page title', 'CG' ); ?></label></th>
				<td>
					<input type="text" name="term_meta[finish_page_title]" id="term_meta[finish_page_title]" value="<?php echo esc_attr( $term_meta['finish_page_title'][0] ) ? esc_attr( $term_meta['finish_page_title'][0] ) : ''; ?>">
					<p class="description"><?php _e( 'Custom Finish page title','CG' ); ?></p>
				</td>
			</tr>

			<tr class="form-field">
				<th scope="row" valign="top"><label for="term_meta[finish_page_extra_text]"><?php _e( 'Finish page extra text', 'CG' ); ?></label></th>
				<td>
					<input type="text" name="term_meta[finish_page_extra_text]" id="term_meta[finish_page_extra_text]" value="<?php echo esc_attr( $term_meta['finish_page_extra_text'][0] ) ? esc_attr( $term_meta['finish_page_extra_text'][0] ) : ''; ?>">
					<p class="description"><?php _e( 'Custom Finish page extra text','CG' ); ?></p>
				</td>
			</tr>

		<?php
		}

		function save_taxonomy_custom_meta( $term_id ) { 
			if ( isset( $_POST['term_meta'] ) ) {
				$t_id = $term_id;

				$term_meta = get_term_meta( $t_id );
				$cat_keys = array_keys( $_POST['term_meta'] );

				//die( var_dump( "<pre>", $_POST['term_meta'] , "<pre>" ) . PHP_EOL .  __FILE__ . ":" . __LINE__  ); 

				foreach ( $cat_keys as $key ) {
					if ( isset ( $_POST['term_meta'][$key] ) ) {

						if ($key == 'question_unblur_seconds'){
							$term_meta[$key] = preg_replace('/\D/', '', $_POST['term_meta'][$key]); 

						}
						else {
							$term_meta[$key] = $_POST['term_meta'][$key];
						}	
					}

					update_term_meta( $t_id, $key, $term_meta[$key] );
				}

				if( isset( $_POST['contest-image-id'] ) && '' !== $_POST['contest-image-id'] ){
					$image = $_POST['contest-image-id'];
					update_term_meta ( $term_id, 'contest-image-id', $image );
				} else {
					update_term_meta ( $term_id, 'contest-image-id', '' );
				}
				
			}
		}
		public function save_category_image ( $term_id, $tt_id ) {
			if( isset( $_POST['contest-image-id'] ) && '' !== $_POST['contest-image-id'] ){
				$image = $_POST['contest-image-id'];
				add_term_meta( $term_id, 'contest-image-id', $image, true );
			}
		}  

		public function save_post( $post_id, $post, $update )
		{
			// get the screen object to decide if we want to inject our scripts
			$screen = get_current_screen();

			if( isset($screen) && $screen->post_type == 'question' ){

				$CG_array = isset($_POST['CG']) ? $_POST['CG'] : array();
				if( count($CG_array) > 0 && isset($CG_array['answer']) ){

					$answers = array();

					if( count($CG_array['answer']) > 0 ){
						foreach ($CG_array['answer']['text'] as $key => $value) {
							$answers[$key]['text'] = $value;
						}

						foreach ($CG_array['answer']['type'] as $key => $value) {
							$answers[$key]['type'] = $value;
						}
					}

					update_post_meta( $post_id, '_answers', $answers );
				}


				if( count($CG_array) > 0 && isset($CG_array['video']) ){
					// get video URL if case
					$videoURL = $CG_array['video']['url'][0];

					update_post_meta( $post_id, '_video', $videoURL );

				}

				if( count($CG_array) > 0 && isset($CG_array['questionType']) ){
					// set image or video question type
					$questionType = $CG_array['questionType'];
					
					update_post_meta( $post_id, '_question_type', $questionType );
				}

			}
		}

		public function add_to_menu_metabox()
		{
			// add meta box to "memes_templates" post type
			add_meta_box(
				$this->the_plugin->alias . '_answers',
				__('Possibles answers', 'CG'),
				array($this, 'answers_html'),
				'question',
				'advanced',
				'high'
			);

			add_meta_box(
				$this->the_plugin->alias . '_question_type',
				__('Question type', 'CG'),
				array($this, 'question_type_html'),
				'question',
				'advanced',
				'high'
			);

			add_meta_box(
				$this->the_plugin->alias . '_video',
				__('Video to guess (Youtube only)', 'CG'),
				array($this, 'video_box_html'),
				'question',
				'advanced',
				'high'
			);


		}

		public function video_box_html() {
			global $post_id;

			$videoURL = get_post_meta( $post_id, '_video', true );

			$html = array();

			$html[] = '<div class="' . ( $this->the_plugin->alias ) . '-video-to-guess-wrapper">';
			$html[] = 	'<ul>';
			$html[] = 		'<li>';
			$html[] = 			'<input type="text" value="' . ( $videoURL ) . '" name="CG[video][url][]" />';
			$html[] = 		'</li>';
			$html[] = 	'</ul>';
			$html[] = '</div>';

			echo implode( "\n", $html );
			
		}

		public function question_type_html() {
			global $post_id;

			$questionType = get_post_meta( $post_id, '_question_type', true );

			$html = array();

			$html[] = '<div class="' . ( $this->the_plugin->alias ) . '-question-type-wrapper">';
			$html[] = 	'<ul>';
			$html[] = 		'<li>';
			$html[] = 			'<select name="CG[questionType]">';
			$html[] = 				'<option value="image" ' . ( $questionType == 'image' ? 'selected' : ''  ) . '>Image</option>';
			$html[] = 				'<option value="video" ' . ( $questionType == 'video' ? 'selected' : ''  ) . '>Video</option>';
			$html[] = 			'</select>';
			$html[] = 		'</li>';

			$html[] = 	'</ul>';

			$html[] = '</div>';

			echo implode( "\n", $html );

		}

		public function answers_html()
		{
			global $post_id;

			//$attachment_id = get_post_meta( $post_id, "_CG_attach_id", true );


			$answers = get_post_meta( $post_id, '_answers', true );
			// debug
			if( 0 ) var_dump('<pre>',$extra,'</pre>');

			$html = array();
			$html[] = '<div class="' . ( $this->the_plugin->alias ) . '-answers-wrapper">';
			$html[] = 	'<ul>';
			if( $answers && is_array($answers) && count($answers) > 0 ){
				foreach ($answers as $answer) {

					$html[] = 		'<li>';
					$html[] = 			'<span class="' . ( $this->the_plugin->alias ) . '-drag-ans"><i class="fa fa-sort" aria-hidden="true"></i></span>';
					$html[] = 			'<span class="' . ( $this->the_plugin->alias ) . '-delete-btn"><i class="fa fa-trash" aria-hidden="true"></i></span>';
					$html[] = 			'<input type="text" value="' . ( $answer['text'] ) . '" name="CG[answer][text][]" />';
					$html[] = 			'<select name="CG[answer][type][]">';
					$html[] = 				'<option value="correct" ' . ( $answer['type'] == 'correct' ? 'selected' : ''  ) . '>Correct</option>';
					$html[] = 				'<option value="wrong" ' . ( $answer['type'] == 'wrong' ? 'selected' : ''  ) . '>Wrong</option>';
					$html[] = 			'</select>';
					$html[] = 		'</li>';
				}
			}

			// default
			else{

				$html[] = 		'<li>';
				$html[] = 			'<span class="' . ( $this->the_plugin->alias ) . '-drag-ans"><i class="fa fa-sort" aria-hidden="true"></i></span>';
				$html[] = 			'<span class="' . ( $this->the_plugin->alias ) . '-delete-btn"><i class="fa fa-trash" aria-hidden="true"></i></span>';
				$html[] = 			'<input type="text" value="" name="CG[answer][text][]" />';
				$html[] = 			'<select name="CG[answer][type][]">';
				$html[] = 				'<option value="correct">Correct</option>';
				$html[] = 				'<option value="wrong">Wrong</option>';
				$html[] = 			'</select>';
				$html[] = 		'</li>';
			}

			$html[] = 	'</ul>';
			$html[] = 	'<a href="#" class="CG-button yellow" id="CG-add-new-row">Add new row</a>';

			$html[] = '</div>';

			echo implode( "\n", $html );
		}

	}
	CGContests::getInstance();
}
