CG_Game = (function ($) {
    "use strict";

    $(document).ready(function(){
        if ($('.CG-finish-text').length > 0) {
            clearInterval(question_time_counter);
        }

        $(".CG-all-wrapper").each(function(){
            var maincontainer   = $(this),
                contest_id = maincontainer.data("contestid"),
                continue_contest_flag = maincontainer.data("continuecontest"),
                show_stats = maincontainer.find('#CG-contest-chart').data("showstatsforcontestid"),
                reset_contest_flag = maincontainer.find('#CG-reset-contest').data("reset_contest"),
                diff_pass = null,
                diff_seconds = null,
                int_game = 0,
                time_elapsed = 0,
                question_time_counter = 0,
                question_time_elapsed = 0,
                nb_seconds_pass = 0,
                loading = $('<div class="CG-loading"><div class="bubblingG"><span id="bubblingG_1"></span><span id="bubblingG_2"></span><span id="bubblingG_3"></span></div></div>');

           
            // init function, autoload
            (function init() {
                triggers();
				
                if (show_stats == null) {
                    if (reset_contest_flag != null) {
                        reset_contest();
                    }
                    else if (continue_contest_flag == 0 || continue_contest == null) {
                        load_question();
                    }
                    else {
                        continue_contest()
                    }
                }
                else {
                    contest_get_charts();
                }
				
				
            })();

            function reset_contest() {
                $('#CG-reset-contest').each(function() {
                    var that = $(this);
                    $.ajax({
                        url: CG_Utils.ajaxurl,
                        dataType: "json",
                        method: 'post',
                        data: {
                            'action': 'CG_ajax_action',
                            'sub_action': 'reset-contest',
                            'contest': reset_contest_flag
                        },
                        // Handle the successful result
                        success: function( response ) {
                            that.css({'color' : '#fff', 'padding' : '20px'});
                            if( response.status == 'valid' && $.trim(response.data)  ){
                                that.text(response.data);
                            }
                            else {
                                if ( $.trim(response.data) ) {
                                    that.text(response.data);
                                } else{
                                    that.text('Contest cannot be reseted! Contest was already reseted or was never played.');
                                }
                            }
                        }
                    });
                });
            }


            function contest_get_charts() 
            {

                $('#CG-contest-chart').each(function() {

                    var width = $(this).width();
                    var that = $(this);

                    $.ajax({
                        url: CG_Utils.ajaxurl,
                        dataType: "json",
                        method: 'post',
                        data: {
                            'action': 'CG_ajax_action',
                            'sub_action': 'contest-chart',
                            'contest': show_stats
                        },
                        // Handle the successful result
                        success: function( response ) {
                            if( response.status == 'valid' && response.data.length > 0  ){

                                google.charts.load('current', {'packages':['line']});
                                google.charts.setOnLoadCallback(drawChart);

                                function drawChart() {
                                    var responseData = response.data;

                                    // Create the data table.
                                    var data = new google.visualization.DataTable();

                                    data.addColumn('string', 'User Name');
                                    data.addColumn('number', 'Obtained Points');

                                    responseData.forEach(function(entry) {
                                        data.addRow([entry['user_name'], parseInt(entry['obtained_points'])]);
                                    });

                                    var options = {
                                        chart: {
                                          title: 'Obtained Points',
                                          subtitle: 'for users that played this contest'
                                        },
                                        width: width,
                                        height: 400,
                                        chartArea: {left: 0, top: 0, width: "100%", height: "100%"}
                                    };

                                    var chart = new google.charts.Line(document.getElementById('CG-contest-chart'));

                                    chart.draw(data, google.charts.Line.convertOptions(options));
                                }
                            }
                            else {
                                that.text('No statistics for this contest.');
                                that.css({'color' : '#fff', 'padding' : '20px'});
                            }
                        }
                    });
                });
            }


            function game_start()
            {
                show_loading();


                var data = {
                    'action': 'CG_ajax_action',
                    'sub_action': 'start-contest',
                    'contest_id': contest_id
                };
                jQuery.post( CG_Utils.ajaxurl, data, function(response) {
                    if( response.status == 'invalid' ){
                        alert( response.msg );
                        return;
                    }else if( response.status == 'valid' ){
                        load_question();
                    }
                }, 'json');


                if (question_time_counter == 0) {

                    auto_count_down();
                }
               
            }

            function continue_contest()
            {
                show_loading();


                var data = {
                    'action': 'CG_ajax_action',
                    'sub_action': 'continue-contest',
                    'contest_id': contest_id
                };
                jQuery.post( CG_Utils.ajaxurl, data, function(response) {
                    if( response.status == 'invalid' ){
                        maincontainer.find(".CG-body").html( response.html );
                        return;
                    }else if( response.status == 'valid' ){
                        maincontainer.find(".CG-body").html( response.html );
                        
                        hide_loading();
                    }
                }, 'json');


                if (question_time_counter == 0) {

                    auto_count_down();
                }
               
            }

            function show_loading()
            {
                maincontainer.find(".CG-body").append( loading );
                loading.show();
            }

            function hide_loading()
            {
                maincontainer.find(".CG-loading").remove();
            }

            function unblur_img( blur )
            {
                maincontainer.find(".CG-img-to-guess img").css({
                    '-webkit-filter': 'blur(' + blur + 'px)',
                    '-moz-filter': 'blur(' + blur + 'px)',
                    '-o-filter': 'blur(' + blur + 'px)',
                    '-ms-filter': 'blur(' + blur + 'px)',
                    'filter': 'blur(' + blur + 'px)'
                });
            }

            function formatTime(seconds) {
              const h = Math.floor(seconds / 3600);
              const m = Math.floor((seconds % 3600) / 60);
              const s = seconds % 60;

              // return [
              //   h,
              //   m > 9 ? m : '0' + m,
              //   s > 9 ? s : '0' + s,
              // ].filter(s => s).join(':');
              if ( m == 1) {
                if ( s == 1 ) {
                    return m + " minute and " + s + " second";
                }
                else {
                    return m + " minute and " + s + " seconds";
                }
              } 
              else {
                if ( s == 1 ) {
                    return m + " minutes and " + s + " second";
                } else {
                    return m + " minutes and " + s + " seconds";
                }
              }
            }

            function diff_change( contest )
            {
                //contest

                var points_elm = maincontainer.find('.CG-current-score-amount-1');

                var blur = 10;

                unblur_img( blur );

                var time_spend = 0;
                var max_point_time = (contest.unblur_seconds * 1000);

                var _nb_of_unblur = max_point_time / 100;

                diff_pass.width( "100%" );
                diff_pass.css('transition', ' width ' + contest.unblur_seconds + "s linear" );

                var cc = 0;
                int_game = setInterval( function(){
                    time_spend += 100;
                    cc++;

                    var _points = Math.ceil( contest.max_points_nb - ( contest.max_points_nb / max_point_time * time_spend ) );
                    points_elm.text(_points);
                    /*
                    var _blur = blur - (cc * blur) / 100;

                    _blur = Math.floor(_blur);
                    unblur_img( _blur );
                    */
                    if( time_spend >= max_point_time ){

                        clearInterval( int_game );
                    }

                }, 100 );

                var nb_sec = contest.unblur_seconds;
                nb_seconds_pass = setInterval( function(){
                    
                    nb_sec--;

                    diff_seconds.text( nb_sec );

                    //var _blur = Math.ceil((nb_sec * blur) / contest.unblur_seconds);
                    var _blur = (nb_sec * blur) / contest.unblur_seconds;
                    unblur_img( _blur );

                    if( nb_sec == 0 ){
                        clearInterval( nb_seconds_pass );
                    }



                }, 1000 );

            }

            function submit_answer()
            {
                clearInterval( int_game );
                clearInterval( nb_seconds_pass );

                var answer = maincontainer.find("input[name='answer']:checked").val();

                if (answer == null || answer == '') {
                    alert ('Please choose a valid answer.');
                    return ;
                }

                var question_id = maincontainer.find(".CG-question-form").data('id');
                var game_id = maincontainer.find(".CG-question-form").data('gameid');
                var points = maincontainer.find('.CG-current-score-amount-1').text();
                
                show_loading();

                var data = {
                    'action'        : 'CG_ajax_action',
                    'sub_action'    : 'check-answer',
                    'question_id'   : question_id,
                    'contest_id'    : contest_id,
                    'answer'        : answer,
                    'game_id'       : game_id,
                    'points'        : points
                };

                jQuery.post( CG_Utils.ajaxurl, data, function(response) {
                    load_question();
                }, 'json');

                //console.log( answer , question_id, points );
            }
			
			function add_fb_share(){
                
				$('.CG-contest-content').each(function(){
					$(this).append('<div class="CG-share"><div class="fb-share-button" data-href="' + window.location.href +'" data-layout="button" data-size="small" data-mobile-iframe="false"><a class="fb-xfbml-parse-ignore" target="_blank" href="https://www.facebook.com/sharer/sharer.php?u=' + window.location.href + '&display=popup&src=sdkpreparse">Share</a></div></div>');
				});

                FB.XFBML.parse();
			}

            function auto_count_down()
            {
                time_elapsed = maincontainer.find('.CG-contest-content').data('timeelapsed');
                
                if (question_time_counter == 0 && maincontainer.find('.CG-current-score').length > 0) {

                    if (time_elapsed > 0) {
                        question_time_elapsed = time_elapsed;
                    } else {
                        question_time_elapsed = 0;
                    }
                    
                    question_time_counter = setInterval( function(){
                       question_time_elapsed += 1;
                        $('.CG-quiz-duration-time').text(formatTime(question_time_elapsed));
                        
                    }, 1000 );
                }
            }

            function load_question()
            {
                show_loading();
                

                var data = {
                    'action': 'CG_ajax_action',
                    'sub_action': 'next-question',
                    'contest_id': contest_id
                };
                jQuery.post( CG_Utils.ajaxurl, data, function(response) {
                    if( response.status == 'valid' ){

                        if( response.page == 'question' ){

                            maincontainer.find(".CG-body").html( response.html );
                            diff_pass = maincontainer.find(".CG-img-difficulty-time-passed");
                            diff_seconds = maincontainer.find(".CG-img-difficulty-seconds");

                            if( $('.CG-video-to-guess').length = 0 && !is_video_on_mobile() ) {
                                diff_change( response.contest  );
                                auto_count_down();
                            }
                            else if( $('.CG-video-to-guess').length > 0 && is_video_on_mobile() ) {
                                var monitor = setInterval(function(){
                                    var elem = document.activeElement;
                                    if(elem && elem.tagName == 'IFRAME'){
                                        clearInterval(monitor);
                                        diff_change( response.contest  );
                                        auto_count_down();
                                    }
                                }, 100);
                                
                            }
                            else if( $('.CG-video-to-guess').length > 0 ) {
                                $('.CG-contest-content #ytplayer').load(function() {
                                    diff_change( response.contest  );
                                    auto_count_down();
                                });
                            } 
                            else {
                                diff_change( response.contest  );
                                auto_count_down();
                            }
                            
                        }else{
                            maincontainer.find(".CG-body").html( response.html );
                        }
                    }else{
                        maincontainer.find(".CG-body").html( response.html );
                    }
					add_fb_share();
                    hide_loading();
                }, 'json');
				
				
            }

            function is_video_on_mobile() {
                var isMobile = false; //initiate as false
                // device detection
                if(/(android|bb\d+|meego).+mobile|avantgo|bada\/|blackberry|blazer|compal|elaine|fennec|hiptop|iemobile|ip(hone|od)|ipad|iris|kindle|Android|Silk|lge |maemo|midp|mmp|netfront|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\/|plucker|pocket|psp|series(4|6)0|symbian|treo|up\.(browser|link)|vodafone|wap|windows (ce|phone)|xda|xiino/i.test(navigator.userAgent) 
                    || /1207|6310|6590|3gso|4thp|50[1-6]i|770s|802s|a wa|abac|ac(er|oo|s\-)|ai(ko|rn)|al(av|ca|co)|amoi|an(ex|ny|yw)|aptu|ar(ch|go)|as(te|us)|attw|au(di|\-m|r |s )|avan|be(ck|ll|nq)|bi(lb|rd)|bl(ac|az)|br(e|v)w|bumb|bw\-(n|u)|c55\/|capi|ccwa|cdm\-|cell|chtm|cldc|cmd\-|co(mp|nd)|craw|da(it|ll|ng)|dbte|dc\-s|devi|dica|dmob|do(c|p)o|ds(12|\-d)|el(49|ai)|em(l2|ul)|er(ic|k0)|esl8|ez([4-7]0|os|wa|ze)|fetc|fly(\-|_)|g1 u|g560|gene|gf\-5|g\-mo|go(\.w|od)|gr(ad|un)|haie|hcit|hd\-(m|p|t)|hei\-|hi(pt|ta)|hp( i|ip)|hs\-c|ht(c(\-| |_|a|g|p|s|t)|tp)|hu(aw|tc)|i\-(20|go|ma)|i230|iac( |\-|\/)|ibro|idea|ig01|ikom|im1k|inno|ipaq|iris|ja(t|v)a|jbro|jemu|jigs|kddi|keji|kgt( |\/)|klon|kpt |kwc\-|kyo(c|k)|le(no|xi)|lg( g|\/(k|l|u)|50|54|\-[a-w])|libw|lynx|m1\-w|m3ga|m50\/|ma(te|ui|xo)|mc(01|21|ca)|m\-cr|me(rc|ri)|mi(o8|oa|ts)|mmef|mo(01|02|bi|de|do|t(\-| |o|v)|zz)|mt(50|p1|v )|mwbp|mywa|n10[0-2]|n20[2-3]|n30(0|2)|n50(0|2|5)|n7(0(0|1)|10)|ne((c|m)\-|on|tf|wf|wg|wt)|nok(6|i)|nzph|o2im|op(ti|wv)|oran|owg1|p800|pan(a|d|t)|pdxg|pg(13|\-([1-8]|c))|phil|pire|pl(ay|uc)|pn\-2|po(ck|rt|se)|prox|psio|pt\-g|qa\-a|qc(07|12|21|32|60|\-[2-7]|i\-)|qtek|r380|r600|raks|rim9|ro(ve|zo)|s55\/|sa(ge|ma|mm|ms|ny|va)|sc(01|h\-|oo|p\-)|sdk\/|se(c(\-|0|1)|47|mc|nd|ri)|sgh\-|shar|sie(\-|m)|sk\-0|sl(45|id)|sm(al|ar|b3|it|t5)|so(ft|ny)|sp(01|h\-|v\-|v )|sy(01|mb)|t2(18|50)|t6(00|10|18)|ta(gt|lk)|tcl\-|tdg\-|tel(i|m)|tim\-|t\-mo|to(pl|sh)|ts(70|m\-|m3|m5)|tx\-9|up(\.b|g1|si)|utst|v400|v750|veri|vi(rg|te)|vk(40|5[0-3]|\-v)|vm40|voda|vulc|vx(52|53|60|61|70|80|81|83|85|98)|w3c(\-| )|webc|whit|wi(g |nc|nw)|wmlb|wonu|x700|yas\-|your|zeto|zte\-/i.test(navigator.userAgent.substr(0,4))) {
                    isMobile = true;
                } 
                return isMobile;
            }

            function triggers() 
            {
                if ($('.CG-contest-list').length == 0) {
                    maincontainer.on("click", "a.CG-start", function(e){
                        e.preventDefault();

                        if (!$(this).attr('disabled')) {
                            game_start();
                        }
                    });

                    maincontainer.on("click", "button.CG-submit", function(e){
                        e.preventDefault();
                        submit_answer();
                    });

                    maincontainer.on("contextmenu", ".CG-image-to-guess", function(e){
                        return false; 
                    });

                }
            }
        });
     });

    // external usage
    return {
    }
})(jQuery);